import { Injectable } from '@angular/core';
import { Spell } from 'src/interfaces/spell';
import { Subject } from 'rxjs';

@Injectable({
  providedIn: 'root',
})
export class SpellsService {
  // Functions

  private _closeSubject = new Subject<number>();

  public closeSubject$ = this._closeSubject.asObservable();

  constructor() {}

  public closeAllOthers(level: number): void {
    this._closeSubject.next(level);
  }

  // Custom Spells

  public customSpells: Spell[] = [];

  /**
   * Returns an array of available spells for the given level and character class.
   * The results come from the official apells array and the custom spells array.
   * @param level The level of the spell.
   * @param characterClass The character class of the spell.
   * @returns An array of available spells.
   */
  public getAvailableSpells(level: number, characterClass?: string): Spell[] {
    let result: Spell[] = [];
    if (characterClass !== undefined) {
      result = this.spells
        .filter((spell) => spell.level === level)
        .filter((spell) => spell.classes.includes(characterClass));
      result.push(
        ...this.customSpells.filter((spell) => spell.level === level),
      );
      return result;
    } else {
      result = this.spells.filter((spell) => spell.level === level);
      result.push(
        ...this.customSpells.filter((spell) => spell.level === level),
      );
      return result;
    }
  }

  /**
   * Deletets a single spell from the custom spells array and the full spells array.
   * @param spellToDelete The spell to be deleted from the custom spells.
   */
  public deleteCustomSpell(spellToDelete: Spell): void {
    const customIndex = this.customSpells.findIndex(
      (spell) => spell.id === spellToDelete.id,
    );
    if (customIndex > -1) {
      this.customSpells.splice(customIndex, 1);
    }
    const fullIndex = this.spells.findIndex(
      (spell) => spell.id === spellToDelete.id,
    );
    if (fullIndex > -1) {
      this.spells.splice(fullIndex, 1);
    }
  }

  //

  private spells: Spell[] = [
    /////////////
    // Level 0 //
    /////////////
    {
      id: 1,
      german: 'Ausbessern',
      english: 'Mending',
      image: 'mending',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'cleric', 'druid', 'wizard', 'sorcerer'],
      timeToCast: 10,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Dieser Zauber repariert eine Bruchstelle oder einen Riss in einem Gegenstand, den du berührst, wie ein zerbrochenes Kettenglied, die beiden Hälften eines zerbrochenen Schlüssels, einen zerrissenen Umhang oder einen lecken Weinschlauch. Solange der Riss oder die Bruchstelle in keiner Dimension größer als 1 Fuß ist, kannst du sie flicken, sodass keine Spur des vorherigen Schadens übrigbleibt.</p>
        <p>Der Zauber kann einen magischen Gegenstand oder ein Konstrukt auf physische Weise reparieren, der Zauber kann einem solchen Gegenstand aber nicht seine Magie wiedergeben.</p>`,
      description_en: `
        <p>This spell repairs a single break or tear in an object you touch, such as broken chain link, two halves of a broken key, a torn clack, or a leaking wineskin. As long as the break or tear is no larger than 1 foot in any dimension, you mend it, leaving no trace of the former damage.</p>
        <p>This spell can physically repair a magic item or construct, but the spell can't restore magic to such an object.</p>
      `,
      school: 'transmutation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 2,
      german: 'Befall',
      english: 'Infestation',
      image: 'infestation',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid', 'sorcerer', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'constitution',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'poison' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du lässt eine Wolke aus Parasiten auf ein Ziel in maximal 30 Fuß Distanz localStorage. Das Ziel muss einen Konstitutionsrettungswurf bestehen, oder 1W6 Giftschaden erleiden und 5 Fuß in eine zufällige Richtung laufen. Ein W4 gibt die Richtung vor:</p>
        <ul>
          <li>1: Norden</li>
          <li>2: Süden</li>
          <li>3: Westen</li>
          <li>4: Osten</li>
        </ul>
        <p>Der Zauber löst keine Gelegenheitsangriffe aus.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um 1W6, wenn du die 5. Stufe (2W6), die 11. Stufe (3W6) und die 17. Stufe (4W6) erreichst.</p>
      `,
      description_en: `
        <p>You cause a cloud of mites, fleas, and other parasites to appear momentarily on one creature you can see within range. The target must succeed on a Constitution saving throw, or it takes 1d6 poison damage and moves 5 feet in a random direction if it can move and its speed is at least 5 feet. Roll a d4 for the direction:
        <ul>
          <li>1: north</li>
          <li>2: south</li>
          <li>3: east</li>
          <li>4: west</li>
          </ul>
        <p>This movement doesn’t provoke opportunity attacks, and if the direction rolled is blocked, the target doesn’t move.</p>
        <p>The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'conjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
    },
    {
      id: 3,
      german: 'Blitzköder',
      english: 'Lightning Lure',
      image: 'lightningLure',
      level: 0,
      isCustom: false,
      classes: ['test', 'sorcerer', 'wizard', 'warlock'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'strength',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 8, damageType: 'lightning' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du wirft eine Blitzfalle auf eine Kreatur in 15 Fuß Distanz. Das Ziel muss einen Stärkerettungswurf bestehen, oder 1W8 Blitzschaden erleiden und 10 Fuß in deine Richtung gezogen werden.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um 1W8, wenn du die 5. Stufe (2W8), die 11. Stufe (3W8) und die 17. Stufe (4W8) erreichst.</p>
      `,
      description_en: `
        <p>You create a lash of lightning energy that strikes at one creature of your choice that you can see within range. The target must succeed on a Strength saving throw or be pulled up to 10 feet in a straight line toward you and then take 1d8 lightning damage if it is within 5 feet of you.</p>
        <p><b>At Higher Levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>

      `,
      school: 'evocation',
      isRanged: true,
      range: 15,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
    },
    {
      id: 4,
      german: 'Botschaft',
      english: 'Message',
      image: 'message',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'wizard', 'sorcerer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Du deutest mit dem Finger auf eine Kreatur in Reichweite und flüsterst eine Botschaft. Das Ziel (und nur das Ziel) hört die Botschaft und kann in einem Flüstern antworten, das nur du hören kannst.</p>
      <p>Du kannst diesen Zauber durch feste Gegenstände hindurch wirken, wenn du das Ziel kennst und weißt, dass es jenseits der Barriere liegt. "Magische Stille", 1 Fuß Stein, 15 Fuß Holz, eine dünne Schicht Blei oder gewöhnliches Metall blockieren den Zauber. Der Zauber muss nicht einer geraden Linie folgen und kann frei um Ecken oder durch Öffnungen reisen.</p>`,
      description_en: `
      <p>You point your finger toward a creature within range and whisper a message. The target (and only the target) hears the message and can reply in a whisper that only you can hear.</p>
      <p>You can cast this spell through solid objects if you are familiar with the target and know it is beyond the barrier. Magical silence, 1 foot of stone, 1 inch of common metal, a thin sheet of lead, or 3 feet of wood blocks the spell. The spell doesn’t have to follow a straight line and can travel freely around corners or through openings.</p>
      `,
      school: 'transmutation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 5,
      german: 'Donnerschlag',
      english: 'Thunderclap',
      image: 'thunderclap',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'druid', 'sorcerer', 'warlock', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'constitution',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'lightning' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du erzeugst einen Knall, der bis zu 100 Fuß weit zu hören ist. Jede Kreatur in Reichweite, außer dir, muss einen Konstitutionsrettungswurf schaffen oder 1W6 Donnerschaden erleiden.</p>
        <p>Der Schaden des Zaubers erhöht sich um 1W6, wenn du die 5. Stufe (2W6), die 11. Stufe (3W6) und die 17. Stufe (4W6) erreichst.</p>
        `,
      description_en: `
        <p>You create a burst of thunderous sound that can be heard up to 100 feet away. Each creature within range, other than you, must succeed on a Constitution saving throw or take 1d6 thunder damage.</p>
        <p>The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'evocation',
      isRanged: false,
      range: 0,
      hasAreaOfEffect: true,
      areaOfEffectType: 'circle',
      diameter: 200,
    },
    {
      id: 6,
      german: 'Dornenpeitsche',
      english: 'Thorn Whip',
      image: 'thornWhip',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'piercing' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du erschaffst eine lange, dornige Peitsche aus Efeu oder einem anderen Pflanzenmaterial, die du auf eine Kreatur in Reichweite richtest. Dein Angriffswurf mit dem Zauberangriffswurf bestimmt, ob der Zauber trifft oder nicht. Bei einem Treffer erleidet das Ziel 1W6 Piercingschaden und du ziehst das Ziel 10 Fuß in deine Richtung. Wenn das Ziel dadurch in deine Reichweite kommt, kannst du es mit einem Angriff mit einer Nahkampfwaffe deiner Wahl angreifen.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um 1W6, wenn du die 5. Stufe (2W6), die 11. Stufe (3W6) und die 17. Stufe (4W6) erreichst.</p>`,
      description_en: `
        <p>You create a long, vine-like whip covered in thorns that lashes out at your command toward a creature in range. Make a melee spell attack against the target. If the attack hits, the creature takes 1d6 piercing damage, and if the creature is Large or smaller, you pull the creature up to 10 feet closer to you.</p>
        <p>This spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 7,
      german: 'Druidenkunst',
      english: 'Druidcraft',
      image: 'druidcraft',
      level: 0,
      isCustom: false,

      classes: ['test', 'druid'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du flüsterst den Geistern der Natur zu und erschaffst innerhalb der Reichweite einen der folgenden Effekte:</p>
        <ul>
          <li>Du erschaffst einen kleinen, harmlosen sensorischen Effekt der vorhersagt, wie das Wetter an deinem Aufenthaltsort für die nächsten 24 Stunden sein wird. Der Effekt könnte sich als goldene Kugel für einen klaren Himmel, als Wolke für Regen, als fallende Schneeflocken für Schnee – und so weiter – manifestieren. Dieser Effekt hält eine Runde lang an.</li>
          <li>Du sorgst dafür, dass augenblicklich eine Blume erblüht, eine Samenkapsel sich öffnet oder eine Blattknospe aufblüht.</li>
          <li>Du erschaffst einen augenblicklichen, harmlosen sensorischen Effekt, wie fallende Blätter, einen Windhauch, die Geräusche eines kleinen Tieres oder den leichten Geruch eines Stinktiers. Der Effekt muss in einem Würfel mit 5 Fuß Kantenlänge passen.</li>
          <li>Du kannst augenblicklich eine Kerze, eine Fackel oder ein kleines Lagerfeuer entzünden oder löschen.</li>
        </ul>
          `,
      description_en: `
        <p>Whispering to the spirits of nature, you create one of the following effects within range:</p>
        <ul>
          <li>You create a tiny, harmless sensory effect that predicts what the weather will be at your location for the next 24 hours. The effect might manifest as a golden orb for clear skies, a cloud for rain, falling snowflakes for snow, and so on. This effect persists for 1 round.</li>
          <li>You instantly make a flower blossom, a seed pod open, or a leaf bud bloom.</li>
          <li>You create an instantaneous, harmless sensory effect, such as falling leaves, a puff of wind, the sound of a small animal, or the faint odor of skunk. The effect must fit in a 5-foot cube.</li>
          <li>You instantly light or snuff out a candle, a torch, or a small campfire.</li>
        </ul>
      `,
      school: 'transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 8,
      german: 'Dröhnende Klinge',
      english: 'Booming Blade',
      image: 'boomingBlade',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'sorcerer', 'warlock', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 8, damageType: 'lightning' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Du schwingst die Waffe, mit der der Zauber gewirkt wurde, und führst mit ihr einen Nahkampfangriff gegen eine Kreatur im Umkreis von 5 Fuß um dich herum aus. Bei einem Treffer erleidet das Ziel die normalen Effekte des Waffenangriffs und wird dann bis zum Beginn deines nächsten Zuges von dröhnender Energie umhüllt. Wenn sich das Ziel bis dahin freiwillig 5 Fuß oder mehr bewegt, erleidet das Ziel 1W8 Donnerschaden und der Zauber endet.</p>
      <p>Der Schaden des Zaubers erhöht sich um 1W8, wenn du die 5. Stufe (2W8), die 11. Stufe (3W8) und die 17. Stufe (4W8) erreichst.</p>
      `,
      description_en: `
      <p>You brandish the weapon used in the spell’s casting and make a melee attack with it against one creature within 5 feet of you. On a hit, the target suffers the weapon attack’s normal effects and then becomes sheathed in booming energy until the start of your next turn. If the target willingly moves 5 feet or more before then, the target takes 1d8 thunder damage, and the spell ends.</p>
      <p>At 5th level, the melee attack deals an extra 1d8 thunder damage to the target on a hit, and the damage the target takes for moving increases to 2d8. Both damage rolls increase by 1d8 at 11th level (2d8 and 3d8) and again at 17th level (3d8 and 4d8).</p>
      `,
      school: 'evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 9,
      german: 'Einfache Illusion',
      english: 'Minor Illusion',
      image: 'minorIllusion',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'wizard', 'warlock', 'sorcerer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Du erschaffst ein Geräusch oder ein Bild eines Gegenstands in Reichweite, das für die Wirkungsdauer anhält. Die Illusion endet auch, wenn du sie als Aktion aufhebst oder diesen Zauber noch einmal wirkst. Wenn du ein Geräusch erschaffst, kann die Lautstärke von einem Flüstern bis zu einem Schrei reichen. Es kann deine Stimme sein, die Stimme eines anderen, das Brüllen eines Löwen, schlagende Trommeln oder ein anderes Geräusch deiner Wahl. Das Geräusch hält für die Wirkungsdauer an, oder du machst einzelne Laute zu verschiedenen Zeiten bis der Zauber endet.</p>
      <p>Wenn du das Bildnis eines Gegenstandes erschaffst - wie das eines Stuhles, schlammiger Fußabdrücke oder einer kleinen Truhe - kann es nicht größer als ein Würfel mit einer Seitenlänge von 1,50m sein. Das Bild kann keine Geräusche, kein Licht, keine Gerüche oder andere sensorische Effekte erzeugen. Körperliche Interaktion mit dem Trugbild offenbart, dass es sich um eine Illusion handelt, weil Dinge es einfach durchdringen können. Eine Kreatur, die ihre Aktion verwendet, um das Bildnis oder das Geräusch zu untersuchen, kann erkennen, dass es sich um eine Illusion handelt, indem sie einen erfolgreichen Wurf auf Intelligenz (Nachforschungen) gegen deinen Zauberrettungswurf-SG ablegt. Wenn die Kreatur die Illusion als das durchschaut, was sie ist, dann verblast sie für die Kreatur.</p>
      `,
      description_en: `
      <p>You create a sound or an image of an object within range that lasts for the duration. The illusion also ends if you dismiss it as an action or cast this spell again.</p>
      <p>If you create a sound, its volume can range from a whisper to a scream. It can be your voice, someone else’s voice, a lion’s roar, a beating of drums, or any other sound you choose. The sound continues unabated throughout the duration, or you can make discrete sounds at different times before the spell ends.</p>
      <p>If you create an image of an object - such as a chair, muddy footprints, or a small chest - it must be no larger than a 5-foot cube. The image can’t create sound, light, smell, or any other sensory effect. Physical interaction with the image reveals it to be an illusion, because things can pass through it. A creature that uses its action to examine the image can determine that it is an illusion with a successful Intelligence (Investigation) check against your spell save DC. If a creature discerns the illusion for what it is, the illusion becomes faint to the creature.</p>
      `,
      school: 'illusion',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 10,
      german: 'Erde Formen',
      english: 'Mold Earth',
      image: 'moldEarth',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'hours',
      canRitual: false,
      isRitual: false,
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: true,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du wählst ein Stück Erde oder Stein in Reichweite, das du sehen kannst und das in einen Würfel von 5 Fuß passt. Du kannst es auf eine der folgenden Arten manipulieren:</p>
        <ul>
          <li>Wenn du einen Bereich mit loser Erde anvisierst, kannst du sie augenblicklich ausheben, über den Boden bewegen und bis zu 5 Fuß entfernt ablegen. Diese Bewegung hat nicht genug Kraft, um Schaden zu verursachen.</li>
          <li>Du lässt Formen, Farben oder beides auf der Erde oder den Steinen erscheinen, indem du Wörter schreibst, Bilder kreierst oder Muster formst. Die Veränderungen halten 1 Stunde lang an.</li>
          <li>Befindet sich die Erde oder der Stein, auf den du zielst, auf dem Boden, verwandelst du ihn in schwieriges Terrain. Alternativ kannst du den Boden auch in normales Gelände verwandeln, wenn er bereits schwieriges Gelände ist. Diese Veränderung hält 1 Stunde lang an.</li>
        </ul>
        <p>Wenn du diesen Zauber mehrmals wirkst, kannst du nicht mehr als zwei seiner nicht-augenblicklichen Effekte gleichzeitig aktiv haben, und du kannst einen solchen Effekt als eine Aktion abbrechen.</p>
      `,
      description_en: `
        <p>You choose a portion of dirt or stone that you can see within range and that fits within a 5-foot cube. You manipulate it in one of the following ways:</p>
        <ul>
          <li>If you target an area of loose earth, you can instantaneously excavate it, move it along the ground, and deposit it up to 5 feet away. This movement doesn’t have enough force to cause damage.</li>
          <li>You cause shapes, colors, or both to appear on the dirt or stone, spelling out words, creating images, or shaping patterns. The changes last for 1 hour.</li>
          <li>If the dirt or stone you target is on the ground, you cause it to become difficult terrain. Alternatively, you can cause the ground to become normal terrain if it is already difficult terrain. This change lasts for 1 hour.</li>
        </ul>
        <p>If you cast this spell multiple times, you can have no more than two of its non-instantaneous effects active at a time, and you can dismiss such an effect as an action.</p>
      `,
      school: 'transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: true,
      areaOfEffectType: 'cube',
      diameter: 5,
    },
    {
      id: 13,
      german: 'Erfrierung',
      english: 'Frostbite',
      image: 'frostbite',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid', 'warlock', 'artificer', 'sorcerer', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'constitution',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'cold' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du verursachst betäubenden Frost auf einer Kreatur in Reichweite, die du sehen kannst. Das Ziel muss einen Rettungswurf auf Konstitution machen. Bei einem misslungenen Rettungswurf erleidet das Ziel 1W6 Kälteschaden und hat Nachteil beim nächsten Angriffswurf, den es vor dem Ende seines nächsten Zuges macht.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W6 wenn du Stufe 5 (auf 2W6), Stufe 11 (auf 3W6) und Stufe 17 (auf 4W6) erreichst.</p>
      `,
      description_en: `
        <p>You cause numbing frost to form on one creature that you can see within range. The target must make a Constitution saving throw. On a failed save, the target takes 1d6 cold damage, and it has disadvantage on the next weapon attack roll it makes before the end of its next turn.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 12,
      german: 'Feuerpfeil',
      english: 'Fire Bolt',
      image: 'fireBolt',
      level: 0,
      isCustom: false,
      classes: ['test', 'sorcerer', 'wizard', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 10, damageType: 'fire' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du schleuderst einen Splitter aus Feuer auf eine Kreatur in Reichweite. Lege einen Fernkampf-Zauberangriff gegen das Ziel ab. Bei einem Treffer erleidet das Ziel 1W10 Feuerschaden. Ein brennbarer Gegenstand, der von diesem Zauber getroffen wird, geht in Flammen auf, wenn er nicht getragen oder in der Hand gehalten wird.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W10 wenn du Stufe 5 (auf 2W10), Stufe 11 (auf 3W10) und Stufe 17 (auf 4W10) erreichst.</p>
      `,
      description_en: `
        <p>You hurl a mote of fire at a creature or object within range. Make a ranged spell attack against the target. On a hit, the target takes 1d10 fire damage. A flammable object hit by this spell ignites if it isn’t being worn or carried.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th level (4d10).</p>
      `,
      school: 'evocation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 13,
      german: 'Flammen Erzeugen',
      english: 'Produce Flame',
      image: 'produceFlames',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid'],
      timeToCast: 0,
      cost: 'action',
      duration: 10,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 8, damageType: 'fire' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Eine flackernde Flamme erscheint in deiner Hand. Die Flamme bleibt für die Wirkungsdauer bestehen und beschädigt weder dich noch deine Ausrüstung. Sie strahlt in einem Radius von 15 Fuß helles Licht und in einem zusätzlichen Radius von 15 Fuß dämmriges Licht ab. Der Zauber endet, wenn du ihn als Aktion aufhebst oder noch einmal wirkst.</p>
        <p>Du kannst mit der Flamme auch angreifen, doch dies beendet den Zauber. Wenn du diesen Zauber wirkst, oder als Aktion in einem späteren Zug, kannst du die Flamme auf eine Kreatur innerhalb von 30 Fuß werfen. Lege einen Fernkampf-Zauberangriff ab. Bei einem Treffer erleidet das Ziel 1W8 Feuerschaden.</p>
        <p>Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
        <p>A flickering flame appears in your hand. The flame remains there for the duration and harms neither you nor your equipment. The flame sheds bright light in a 10-foot radius and dim light for an additional 10 feet. The spell ends if you dismiss it as an action or if you cast it again.</p>
        <p>You can also attack with the flame, although doing so ends the spell. When you cast this spell, or as an action on a later turn, you can hurl the flame at a creature within 30 feet of you. Make a ranged spell attack. On a hit, the target takes 1d8 fire damage.</p>
        <p>The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'conjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 14,
      german: 'Flammen kontrollieren',
      english: 'Control Flames',
      image: 'controlFlames',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid', 'artificer', 'sorcerer', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'hours',
      canRitual: false,
      isRitual: false,
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du wählst ein nicht-magisches Feuer in Reichweite, das du sehen kannst, und das in einem Würfel mit einer Seitenlänge von 5 Fuß passt. Du beeinflusst es auf eine der folgenden Arten:</p>
        <ul>
          <li>Du dehnst die Flamme augenblicklich 5 Fuß in eine Richtung aus, vorausgesetzt, dass Holz oder anderer Brennstoff an der neuen Stelle vorhanden ist.</li>
          <li>Du löschst die Flammen innerhalb des Würfels augenblicklich.</li>
          <li>Du verdoppelst oder halbierst den Bereich des hellen und schwachen Lichts, das die Flamme ausstrahlt, veränderst ihre Farbe oder beides. Die Veränderung hält 1 Stunde lang an.</li>
          <li>Du lässt einfache Formen - wie die vage Form einer Kreatur, eines unbelebten Objekts oder eines Ortes - in den Flammen erscheinen und nach Belieben beleben. Die Formen bleiben 1 Stunde lang bestehen.</li>
        </ul>
        <p>Wenn du diesen Zauber mehrmals wirkst, kannst du bis zu drei seiner nicht-augenblicklichen Effekte gleichzeitig aktiv haben, und du kannst einen solchen Effekt als Aktion abbrechen.</p>
      `,
      description_en: `
        <p>You choose nonmagical flame that you can see within range and that fits within a 5-foot cube. You affect it in one of the following ways:</p>
        <ul>
          <li>You instantaneously expand the flame 5 feet in one direction, provided that wood or other fuel is present in the new location.</li>
          <li>You instantaneously extinguish the flames within the cube.</li>
          <li>You double or halve the area of bright light and dim light cast by the flame, change its color, or both. The change lasts for 1 hour.</li>
          <li>You cause simple shapes - such as the vague form of a creature, an inanimate object, or a location - to appear within the flames and animate as you like. The shapes last for 1 hour.</li>
        </ul>
        <p>If you cast this spell multiple times, you can have up to three of its non-instantaneous effects active at a time, and you can dismiss such an effect as an action.</p>
      `,
      school: 'transmutation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: true,
      areaOfEffectType: 'cube',
      diameter: 5,
    },
    {
      id: 15,
      german: 'Freundschaft',
      english: 'Friends',
      image: 'friends',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'sorcerer', 'warlock', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Für die Wirkungsdauer hast du einen Vorteil auf alle Charisma-Würfe, die auf eine Kreatur deiner Wahl gewirkt werden, die dir nicht feindlich gesonnen sind. Wenn der Zauber endet, begreift die Kreatur, dass du Magie verwendet hast, um ihre Stimmung zu beeinflussen und wird feindselig. Eine Kreatur, die zu Gewalt neigt, könnte dich angreifen. Andere Kreaturen könnten sich (nach Entscheidung des Spielleiters) andere Möglichkeiten suchen, um sich zu rächen, abhängig von der Art, wie du mit ihr interagiert hast.</p>
      `,
      description_en: `
        <p>For the duration, you have advantage on all Charisma checks directed at one creature of your choice that isn’t hostile toward you. When the spell ends, the creature realizes that you used magic to influence its mood and becomes hostile toward you. A creature prone to violence might attack you. Another creature might seek retribution in other ways (at the DM’s discretion), depending on the nature of your interaction with it.</p>
      `,
      school: 'enchantment',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 16,
      german: 'Gedankensplitter',
      english: 'Mind Sliver',
      image: 'mindSliver',
      level: 0,
      isCustom: false,
      classes: ['test', 'sorcerer', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,

      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'intelligence',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'psychic' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du treibst einen verstörenden Splitter psychischer Energie in den Geist einer Kreatur, die du in Reichweite sehen kannst. Das Ziel muss einen erfolgreichen Rettungswurf auf Intelligenz durchführen, sonst nimmt es 1W6 psychischen Schaden und muss 1W4 von seinem nächsten Rettungswurf vor Ende deines nächsten Zuges abziehen.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W6 wenn du Stufe 5 (auf 2W6), Stufe 11 (auf 3W6) und Stufe 17 (auf 4W6) erreichst.</p>
      `,
      description_en: `
        <p>You drive a disorienting spike of psychic energy into the mind of one creature you can see within range. The target must succeed on an Intelligence saving throw or take 1d6 psychic damage and subtract 1d4 from the next saving throw it makes before the end of your next turn.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'enchantment',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 17,
      german: 'Gehässiger Spott',
      english: 'Vicious Mockery',
      image: 'viciousMockery',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'wisdom',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 4, damageType: 'psychic' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du rufst einer Kreatur in Richweite, die du sehen kannst, eine wahre Flut von Beleidigungen entgegen, in die subtile Verzauberungen gewebt sind. Wenn das Ziel dich hören kann (es braucht dich nicht zu verstehen), muss ihm ein Weisheitsrettungswurf gelingen, um nicht 1W4 psychischen Schaden zu erleiden und beim nächsten Angriffswurf im Nachteil zu sein, den es bis zum Einde seines nächsten Zuges ausführt.</p>
        <p><b>Auf höheren Graden:</b> Der Schaden des Zaubers steigt jeweils um 1W4 bei Erreichen der 5. (2W4), 11. (3W4) und 17. Stufe (4W4).</p>`,
      description_en: `
        <p>You unleash a string of insults laced with subtle enchantments at a creature you can see within range. If the target can hear you (though it need not understand you), it must succeed on a Wisdom saving throw or take 1d4 psychic damage and have disadvantage on the next attack roll it makes before the end of its next turn.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d4 when you reach 5th level (2d4), 11th level (3d4), and 17th level (4d4).</p>
      `,
      school: 'enchantment',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 18,
      german: 'Gift versprühen',
      english: 'Poison Spray',
      image: 'poisonSpray',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid', 'sorcerer', 'warlock', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'constitution',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 12, damageType: 'poison' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du streckst deine Hand in Richtung einer Kreatur in Reichweite, die du sehen kannst, und erzeugst eine Wolke aus ekelhaftem Gas aus deiner Handfläche. Die Kreatur muss einen Rettungswurf auf Konstitution schaffen, sonst erleidet sie 1W12 Giftschaden.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W12 wenn du Stufe 5 (auf 2W12), Stufe 11 (auf 3W12) und Stufe 17 (auf 4W12) erreichst.</p>
      `,
      description_en: `
        <p>You extend your hand toward a creature you can see within range and project a puff of noxious gas from your palm. The creature must succeed on a Constitution saving throw or take 1d12 poison damage.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d12 when you reach 5th level (2d12), 11th level (3d12), and 17th level (4d12).</p>
      `,
      school: 'conjuration',
      isRanged: true,
      range: 10,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 19,
      german: 'Grünfeuerklinge',
      english: 'Green-Flame Blade',
      image: 'greenFlameBlade',
      level: 0,
      isCustom: false,
      classes: ['test', 'sorcerer', 'warlock', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Als Teil der Aktion, mit der du diesen Zauber wirkst, musst du einen Nahkampfangriff mit einer Waffe gegen eine Kreatur in der Reichweite des Zaubers ausführen, sonst misslingt der Zauber. Bei einem Treffer erleidet das Ziel die normalen Auswirkungen des Angriffs, und grünes Feuer springt vom Ziel auf eine andere Kreatur deiner Wahl, die du sehen kannst und die sich innerhalb von 5 Fußn zum Ziel befindet. Die zweite Kreatur erleidet Feuerschaden gleich dem Modifikator deines Attributs zum Zauberwirken.</p>
      <p><b>Auf höheren Stufen:</b> Auf der 5. Stufe fügt der Nahkampfangriff dem Ziel zusätzlich 1W8 Punkte Feuerschaden zu, und der Schaden, den das zweite Ziel erleidet, steigt um 1W8 + der Modifikator deines Attributs zum Zauberwirken. Beide Schadensarten steigen in der 11. und 17. Stufe um 1W8.</p>
      `,
      description_en: `
      <p>As part of the action used to cast this spell, you must make a melee attack with a weapon against one creature within the spell’s range, otherwise the spell fails. On a hit, the target suffers the weapon attack’s normal effects, and green fire leaps from the target to a different creature of your choice that you can see within 5 feet of it. The second creature takes fire damage equal to your spellcasting ability modifier.</p>
      <p><b>At higher levels:</b> At 5th level, the melee attack deals an extra 1d8 fire damage to the target, and the fire damage to the second creature increases to 1d8 + your spellcasting ability modifier. Both damage rolls increase by 1d8 at 11th level and 17th level.</p>
      `,
      school: 'evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 20,
      isCustom: false,
      german: 'Göttliche Führung',
      english: 'Guidance',
      image: 'guidance',
      classes: ['test', 'cleric', 'druid'],
      level: 0,
      cost: 'action',
      duration: 1,
      durationType: 'minutes',
      timeToCast: 0,
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        Du berührst eine bereitwillige Kreatur. Einmal vor dem Ende des Zaubers kann das Ziel mit einem W4 würfeln und das Ergebnis zu einem Attributswurf seiner Wahl addieren. Es kann mit dem W4 vor oder nach dem Attributswurf würfeln. Dann endet der Zauber.
      `,
      description_en: `
        You touch one willing creature. Once before the spell ends, the target can roll a d4 and add the number rolled to one ability check of its choice. It can roll the die before or after making the ability check. The spell then ends.
      `,
      school: 'divination',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 21,
      german: 'Heilige Flamme',
      english: 'Sacred Flame',
      image: 'sacredFlame',
      level: 0,
      isCustom: false,
      classes: ['test', 'cleric'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'strength',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 8, damageType: 'radiant' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Flammengleiches Licht senkt sich auf eine Kreatur in Reichweite, die du sehen kannst, herab. Die Kreatur muss einen Rettungswurf auf Geschicklichkeit schaffen, sonst erleidet sie 1W8 gleißenden Schaden. Bei einem Rettungswurf erhält das Ziel keinen Vorteil aus Deckung.</p>
      <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
      <p>Flame-like radiance descends on a creature that you can see within range. The target must succeed on a Dexterity saving throw or take 1d8 radiant damage. The target gains no benefit from cover for this saving throw.</p>
      <p><b>At higher levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 22,
      german: 'Kalte Hand',
      english: 'Chill Touch',
      image: 'chillTouch',
      level: 0,
      isCustom: false,
      classes: ['test', 'sorcerer', 'warlock', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 8, damageType: 'necrotic' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Du erschaffst eine gespenstische, skelettierte Hand im Bereich einer Kreatur in Reichweite. Mache einen Fernkampf-Zauberangriff gegen die Kreatur, um sie mit der Kälte des Grabes zu attackieren. Bei einem Treffer erleidet die Kreatur 1W8 nekrotischen Schaden und kann bis zu Beginn deines nächsten Zuges keine Trefferpunkt zurückbekommen. Bis dann hält sich die Hand an dem Ziel fest.</p>
      <p>Wenn du eine untote Kreatur triffst, hat sie außerdem Nachteil auf Angriffswürfe gegen dich bis zum Ende deines nächsten Zuges.</p>
      <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
      <p>You create a ghostly, skeletal hand in the space of a creature within range. Make a ranged spell attack against the creature to assail it with the chill of the grave. On a hit, the target takes 1d8 necrotic damage, and it can’t regain hit points until the start of your next turn. Until then, the hand clings to the target.</p>
      <p>If you hit an undead target, it also has disadvantage on attack rolls against you until the end of your next turn.</p>
      <p><b>At higher levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'necromancy',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 23,
      german: 'Klingenbann',
      english: 'Blade Ward',
      image: 'bladeWard',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'sorcerer', 'warlock', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 10,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Du streckst die Hand aus und zeichnest ein Zeichen des Schutzes in die Luft. Bis zum Ende deines nächsten Zuges hast du Resistenz gegen Wucht-, Hieb- und Stichschaden, der von Angriffen mit Waffen verursacht wird.</p>
      `,
      description_en: `
      <p>You extend your hand and trace a sigil of warding in the air. Until the end of your next turn, you have resistance against bludgeoning, piercing, and slashing damage dealt by weapon attacks.</p>
      `,
      school: 'abjuration',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 24,
      german: 'Kältestrahl',
      english: 'Ray of Frost',
      image: 'rayOfFrost',
      level: 0,
      isCustom: false,
      classes: ['test', 'sorcerer', 'wizard', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 8, damageType: 'cold' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Ein eisiger Strahl aus blau-weißem Licht schießt auf eine Kreatur in Reichweite zu. Lege einen Fernkampf-Zauberangriff gegen das Ziel ab. Bei einem Treffer erleidet die Kreatur 1W8 Kälteschaden und ihre Bewegungsrate wird bis zum Beginn deines nächsten Zuges um 10 Fuß verringert.</p>
      <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
      <p>A frigid beam of blue-white light streaks toward a creature within range. Make a ranged spell attack against the target. On a hit, it takes 1d8 cold damage, and its speed is reduced by 10 feet until the start of your next turn.</p>
      <p><b>At higher levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 25,
      german: 'Lagerfeuer erschaffen',
      english: 'Create Bonfire',
      image: 'createBonfire',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid', 'sorcerer', 'warlock', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'strength',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 8, damageType: 'fire' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Du erschaffst ein Lagerfeuer in Reichweite auf dem Boden, den du sehen kannst. Bis der Zauber endet, füllt das Lagerfeuer einen Würfel von 5 Fußn. Jede Kreatur, die sich zum Zeitpunkt des Zaubers im Bereich des Feuers befindet, muss einen Rettungswurf auf Geschicklichkeit ablegen oder 1W8 Feuerschaden erleiden. Eine Kreatur muss den Rettungswurf auch machen, wenn sie den Raum des Lagerfeuers zum ersten Mal in einem Zug betritt oder ihren Zug dort beendet.</p>
      <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
      <p>You create a bonfire on ground that you can see within range. Until the spell ends, the magic bonfire fills a 5-foot cube. Any creature in the bonfire’s space when you cast the spell must succeed on a Dexterity saving throw or take 1d8 fire damage. A creature must also make the saving throw when it enters the bonfire’s space for the first time on a turn or ends its turn there.</p>
      <p><b>At higher levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'conjuration',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: true,
      areaOfEffectType: 'cube',
      diameter: 5,
    },
    {
      id: 26,
      german: 'Licht',
      english: 'Light',
      image: 'light',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'cleric', 'druid', 'sorcerer', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'hours',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Du berührst einen Gegenstand, der nicht größer als 10 Fuß in einer beliebigen Dimension ist. Bis der Zauber endet, strahlt das Objekt helles Licht in einem Radius von 20 Fuß und schwaches Licht für weitere 20 Fuß aus. Das Licht kann nach Belieben gefärbt werden. Wenn du das Objekt vollständig mit etwas Undurchsichtigem abdeckst, wird das Licht blockiert. Der Zauber endet, wenn du ihn erneut wirkst oder ihn als Aktion abbrichst.</p>
      <p>Wenn du ein Objekt anvisierst, das von einer feindlichen Kreatur gehalten oder getragen wird, muss diese Kreatur einen Rettungswurf auf Geschicklichkeit bestehen, um den Zauber zu vermeiden.</p>
      `,
      description_en: `
      <p>You touch one object that is no larger than 10 feet in any dimension. Until the spell ends, the object sheds bright light in a 20-foot radius and dim light for an additional 20 feet. The light can be colored as you like. Completely covering the object with something opaque blocks the light. The spell ends if you cast it again or dismiss it as an action.</p>
      <p>If you target an object held or worn by a hostile creature, that creature must succeed on a Dexterity saving throw to avoid the spell.</p>
      `,
      school: 'evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: 'circle',
      diameter: 40,
    },
    {
      id: 27,
      german: 'Magierhand',
      english: 'Mage Hand',
      image: 'mageHand',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'sorcerer', 'warlock', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Eine gespenstische, schwebende Hand erscheint an einem Punkt deiner Wahl in Reichweite. Die Hand bleibt für die Wirkungsdauer bestehen oder bis du sie mit einer Aktion wegschickst. Die Hand verschwindet, wenn sie sich weiter als 30 Fuß von dir entfernt oder du den Zauber noch einmal wirkst.</p>
      <p>Du kannst eine Aktion verwenden, um die Hand zu kontrollieren. Du kannst die Hand verwenden, um Gegenstände zu manipulieren, verschlossene Türen oder Behälter zu öffnen, einen Gegenstand aus einem geöffneten Behälter zu holen oder ihn zu verstauen, oder den Inhalt einer Phiole auszugießen. Du kannst die Hand immer wenn du sie verwendest bis zu 9m weit bewegen.</p>
      <p>Die Hand kann nicht angreifen, keine magischen Gegenstände aktivieren oder mehr als 10 Pfund tragen.</p>
      `,
      description_en: `
      <p>A spectral, floating hand appears at a point you choose within range. The hand lasts for the duration or until you dismiss it as an action. The hand vanishes if it is ever more than 30 feet away from you or if you cast this spell again.</p>
      <p>You can use your action to control the hand. You can use the hand to manipulate an object, open an unlocked door or container, stow or retrieve an item from an open container, or pour the contents out of a vial. You can move the hand up to 30 feet each time you use it.</p>
      <p>The hand can’t attack, activate magic items, or carry more than 10 pounds.</p>
      `,
      school: 'conjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 28,
      german: 'Magiestein',
      english: 'Magic Stone',
      image: 'magicStone',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid', 'Hexenmeister'],
      timeToCast: 0,
      cost: 'bonus',
      duration: 1,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'bludgeoning' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Du berührst ein bis drei Kieselsteine und belegst sie mit Magie. Du oder eine andere Person kann mit einem der Kieselsteine einen Fernzauberangriff durchführen, indem du ihn wirfst oder mit einer Schleuder schleuderst. Wenn du ihn wirfst, hat er eine Reichweite von 60 Fuß. Wenn jemand anderes mit dem Kieselstein angreift, addiert dieser Angreifer deinen Zaubermodifikator, nicht den des Angreifers, zum Angriffswurf. Bei einem Treffer erleidet das Ziel Wuchtschaden in Höhe von 1W6 + deinem Zaubermodifikator. Treffer oder Fehlschuss, der Zauber endet dann auf dem Stein.</p>
      <p>Wenn du diesen Zauber erneut wirkst, endet der Zauber auf allen Steinen, die noch davon betroffen sind, vorzeitig.</p>
      `,
      description_en: `
      <p>You touch one to three pebbles and imbue them with magic. You or someone else can make a ranged spell attack with one of the pebbles by throwing it or hurling it with a sling. If thrown, it has a range of 60 feet. If someone else attacks with the pebble, that attacker adds your spellcasting ability modifier, not the attacker’s, to the attack roll. On a hit, the target takes bludgeoning damage equal to 1d6 + your spellcasting ability modifier. Hit or miss, the spell then ends on the stone.</p>
      <p>If you cast this spell again, the spell ends on any pebbles still affected by your previous casting.</p>
      `,
      school: 'transmutation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 29,
      german: 'Resistenz',
      english: 'Resistance',
      image: 'resistance',
      level: 0,
      isCustom: false,
      classes: ['test', 'cleric', 'druid', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Du berührst eine willige Kreatur. Einmal bevor der Zauber endet, kann das Ziel einen W4 werfen und die gewürfelte Zahl zu einem Rettungswurf seiner Wahl addieren. Es kann den Würfel werfen, bevor oder nachdem es den Rettungswurf gemacht hat. Der Zauber endet dann.</p>
      `,
      description_en: `
      <p>You touch one willing creature. Once before the spell ends, the target can roll a d4 and add the number rolled to one saving throw of its choice. It can roll the die before or after making the saving throw. The spell then ends.</p>
      `,
      school: 'abjuration',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 30,
      german: 'Schauriger Strahl',
      english: 'Eldritch Blast',
      image: 'eldritchBlast',
      level: 0,
      isCustom: false,
      classes: ['test', 'Hexenmeister'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 10, damageType: 'force' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Ein Strahl aus knisternder Energie schießt auf eine Kreatur in Reichweite zu. Lege einen Fernkampf-Zauberangriff gegen das Ziel ab. Bei einem Treffer erleidet das Ziel 1W10 Energieschaden.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W10 wenn du Stufe 5 (auf 2W10), Stufe 11 (auf 3W10) und Stufe 17 (auf 4W10) erreichst.</p>
      `,
      description_en: `
        <p>A beam of crackling energy streaks toward a creature within range. Make a ranged spell attack against the target. On a hit, the target takes 1d10 force damage.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th level (4d10).</p>
      `,
      school: 'evocation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 31,
      german: 'Schockgriff',
      english: 'Shocking Grasp',
      image: 'shockingGrasp',
      level: 0,
      isCustom: false,
      classes: ['test', 'sorcerer', 'wizard', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 8, damageType: 'lightning' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Blitze springen aus deinen Händen und verpassen einer Kreatur, die du zu berühren versuchst, einen Schock. Führe einen Nahkampf-Zauberangriff gegen das Ziel durch. Du hast einen Vorteil beim Angriffswurf, wenn das Ziel Rüstung trägt, die aus Metall besteht. Bei einem Treffer erleidet die Kreatur 1W8 Blitzschaden und kann bis zum Beginn deines nächsten Zuges keine Reaktion durchführen.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
        <p>Lightning springs from your hand to deliver a shock to a creature you try to touch. Make a melee spell attack against the target. You have advantage on the attack roll if the target is wearing armor made of metal. On a hit, the target takes 1d8 lightning damage, and it can’t take reactions until the start of its next turn.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 32,
      german: 'Schwertexplosion',
      english: 'Sword Burst',
      image: 'swordBurst',
      level: 0,
      isCustom: false,
      classes: ['test', 'sorcerer', 'warlock', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'strength',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'force' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Für einen Moment fegt eine Schar spektraler Klingen in Kreisform um dich herum. Alle Kreaturen innerhalb von 5 Fuß müssen einen Rettungswurf auf Geschicklichkeit ausführen, ansonsten erleiden sie 1W6 Energieschaden.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W6 wenn du Stufe 5 (auf 2W6), Stufe 11 (auf 3W6) und Stufe 17 (auf 4W6) erreichst.</p>
      `,
      description_en: `
        <p>You create a momentary circle of spectral blades that sweep around you. Each creature within range, other than you, must succeed on a Dexterity saving throw or take 1d6 force damage.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'conjuration',
      isRanged: false,
      range: 0,
      hasAreaOfEffect: true,
      areaOfEffectType: 'circle',
      diameter: 10,
    },
    {
      id: 33,
      german: 'Shillelagh',
      english: 'Shillelagh',
      image: 'shillelagh',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid'],
      timeToCast: 0,
      cost: 'bonus',
      duration: 1,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Das Holz einer Keule oder eines Kampfstabs, die du in der Hand hältst, ist mit der Kraft der Natur durchdrungen. Während dieser Zeit kannst du deine Zauberfähigkeit anstelle von Stärke für die Angriffs- und Schadenswürfe von Nahkampfangriffen mit dieser Waffe verwenden, und der Schadenswürfel der Waffe wird zu einem W8. Die Waffe wird außerdem magisch, falls sie es nicht schon ist. Der Zauber endet, wenn du ihn erneut wirkst oder wenn du die Waffe loslässt.</p>
      `,
      description_en: `
        <p>The wood of a club or quarterstaff you are holding is imbued with nature’s power. For the duration, you can use your spellcasting ability instead of Strength for the attack and damage rolls of melee attacks using that weapon, and the weapon’s damage die becomes a d8. The weapon also becomes magical, if it isn’t already. The spell ends if you cast it again or if you let go of the weapon.</p>
      `,
      school: 'transmutation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 34,
      german: 'Säurespritzer',
      english: 'Acid Splash',
      image: 'acidSplash',
      level: 0,
      isCustom: false,
      classes: ['test', 'sorcerer', 'wizard', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'strength',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'acid' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du schleuderst eine Blase aus Säure. Wähle eine Kreatur in Reichweite oder zwei Kreaturen in Reichweite, die sich innerhalb von 5 Fuß voneinander befinden. Das Ziel muss einen Rettungswurf auf Geschicklichkeit bestehen oder erleidet 1W6 Säureschaden.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W6 wenn du Stufe 5 (auf 2W6), Stufe 11 (auf 3W6) und Stufe 17 (auf 4W6) erreichst.</p>
      `,
      description_en: `
        <p>You hurl a bubble of acid. Choose one creature within range, or choose two creatures within range that are within 5 feet of each other. A target must succeed on a Dexterity saving throw or take 1d6 acid damage.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'conjuration',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: true,
      areaOfEffectType: 'circle',
      diameter: 5,
    },
    {
      id: 35,
      german: 'Tanzende Lichter',
      english: 'Dancing Lights',
      image: 'dancingLights',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'sorcerer', 'wizard', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du erschaffst bis zu vier fackelgroße Lichter in Reichweite, die als Fackeln, Laternen oder leuchtende Kugeln erscheinen, die für die Dauer der Aktion in der Luft schweben. Du kannst die vier Lichter auch zu einer leuchtenden, vage humanoiden Form von mittlerer Größe kombinieren. Unabhängig davon, welche Form du wählst, verströmt jedes Licht ein schwaches Licht in einem Radius von 10 Fuß. Als Bonusaktion in deinem Zug kannst du die Lichter bis zu 300 Fuß weit an einen neuen Platz in Reichweite bewegen. Ein Licht muss sich in einem Umkreis von 20 Fußn um ein anderes durch diesen Zauber erzeugtes Licht befinden, und ein Licht erlischt, wenn es den Wirkungsbereich des Zaubers verlässt.</p>
      `,
      description_en: `
        <p>You create up to four torch-sized lights within range, making them appear as torches, lanterns, or glowing orbs that hover in the air for the duration. You can also combine the four lights into one glowing vaguely humanoid form of Medium size. Whichever form you choose, each light sheds dim light in a 10-foot radius.</p>
        <p>As a bonus action on your turn, you can move the lights up to 60 feet to a new spot within range. A light must be within 20 feet of another light created by this spell, and a light winks out if it exceeds the spell’s range.</p>
      `,
      school: 'evocation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 36,
      german: 'Taschenspielerei',
      english: 'Prestidigitation',
      image: 'prestidigitation',
      level: 0,
      isCustom: false,
      classes: ['test', 'bard', 'sorcerer', 'wizard', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'hours',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Dies ist ein einfacher Zaubertrick, den Zauberlehrlinge zum Üben verwenden. Du erzeugst einen der folgenden magischen Effekte in Reichweite:</p>
        <ul>
          <li>Du erzeugst einen unmittelbaren, harmlosen sensorischen Effekt, etwa einen Funkenregen, einen Windstoß, eine leise Melodie oder einen merkwürdigen Geruch.</li>
          <li>Du entzündest oder löschst unmittelbar eine Kerze, eine Fackel oder ein kleines Lagerfeuer.</li>
          <li>Du kannst unmittelbar einen Gegenstand, der nicht größer als ein Würfel mit 1 Fuß Kantenlänge ist, säubern oder verschmutzen.</li>
          <li>Du kannst nichtlebendes Material, das nicht größer als ein Würfel mit 1 Fußn Kantenlänge ist, abkühlen, erhitzen oder würzen. Dies hält eine Stunde lang an.</li>
          <li>Du lässt einen Farbfleck, ein Mal oder ein Symbol eine Stunde lang auf einem Gegenstand oder einer Oberfläche erscheinen.</li>
          <li>Du erzeugst ein nichtmagisches Schmuckstück oder ein illusorisches Bild, das in deine Hand passt und das bis zum Ende deines nächsten Zuges erhalten bleibt.</li>
        </ul>
        <p>Wirkst du diesen Zauber mehrmals, können bis zu drei der langfristigen Effekte gleichzeitig aktiv sein. Du kannst einen solchen Effekt als Aktion beenden.</p>
      `,
      description_en: `
        <p>This spell is a minor magical trick that novice spellcasters use for practice. You create one of the following magical effects within range:</p>
        <ul>
          <li>You create an instantaneous, harmless sensory effect, such as a shower of sparks, a puff of wind, faint musical notes, or an odd odor.</li>
          <li>You instantaneously light or snuff out a candle, a torch, or a small campfire.</li>
          <li>You instantaneously clean or soil an object no larger than 1 cubic foot.</li>
          <li>You chill, warm, or flavor up to 1 cubic foot of nonliving material for 1 hour.</li>
          <li>You make a color, a small mark, or a symbol appear on an object or a surface for 1 hour.</li>
          <li>You create a nonmagical trinket or an illusory image that can fit in your hand and that lasts until the end of your next turn.</li>
        </ul>
        <p>If you cast this spell multiple times, you can have up to three of its non-instantaneous effects active at a time, and you can dismiss such an effect as an action.</p>
      `,
      school: 'transmutation',
      isRanged: true,
      range: 10,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 37,
      isCustom: false,
      german: 'Thaumaturgie',
      english: 'Thaumaturgy',
      image: 'thaumaturgy',
      classes: ['test', 'cleric'],
      level: 0,
      cost: 'action',
      duration: 1,
      durationType: 'minutes',
      timeToCast: 0,
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du manifestierst ein kleines Wunder, ein Zeichen übernatürlicher Macht, in Reichweite. Du kannst einen der folgenden magischen Effekte in Reichweite erschaffen:</p>
        <ul>
          <li>Deine Stimme dröhnt für 1 Minute dreimal so laut, wie normal.</li>
          <li>Du lässt Flammen flackern, heller oder dunkler werden oder die Farbe wechseln. All dies hält 1 Minute an.</li>
          <li>Du erzeugst für 1 Minute harmlose Erschütterungen im Boden.</li>
          <li>Du erschaffst ein kurzes Geräusch, das von einem Punkt deiner Wahl in Reichweite ertönt, wie ein Grollen von Donner, den Ruf eines Raben oder ein unheilvolles Flüstern.</li>
          <li>Du lässt eine nicht verriegelte Tür oder ein Fenster auffliegen oder zuschlagen.</li>
          <li>Du änderst für 1 Minute das Aussehen deiner Augen.</li>
        </ul>
        <p>Wenn du diesen Zauber mehrmals wirkst, kannst du bis zu drei der nicht sofortigen Effekte gleichzeitig aktiviert haben und du kannst solche Effekte als Aktion aufheben.</p>
      `,
      description_en: `
        <p>You manifest a minor wonder, a sign of supernatural power, within range. You create one of the following magical effects within range.</p>
        <ul>
          <li>Your voice booms up to three times as loud as normal for 1 minute.</li>
          <li>You cause flames to flicker, brighten, dim, or change color for 1 minute.</li>
          <li>> You cause harmless tremors in the ground for 1 minute.</li>
          <li>You create an instantaneous sound that originates from a point of your choice within range, such as a rumble of thunder, the cry of a raven, or ominous whispers.</li>
          <li>You instantaneously cause an unlocked door or window to fly open or slam shut.</li>
          <li>You alter the appearance of your eyes for 1 minute.</li>
        <p>If you cast this spell multiple times, you can have up to three of its 1-minute effects active at a time, and you can dismiss such an effect as an action.</p>
      `,
      school: 'transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 38,
      isCustom: false,
      german: 'Totenläuten',
      english: 'Toll the Dead',
      image: 'tollTheDead',
      classes: ['test', 'cleric', 'warlock', 'wizard'],
      level: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      timeToCast: 0,
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'wisdom',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 8, damageType: 'necrotic' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du zeigen auf eine Kreatur, die Sie in Reichweite sehen können, und der Klang einer traurigen Glocke erfüllt für einen Moment die Luft um sie herum. Dem Ziel muss ein Weisheitswurf gelingen oder es erleidet 1W8 nekrotischen Schaden. Wenn dem Ziel einer seiner Trefferpunkte fehlt, erleidet es stattdessen 1W12 nekrotischen Schaden.

        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um einen Würfel, wenn du 5 erreichstth Stufe (2W8 oder 2W12), 11th Stufe (3W8 oder 3W12) und 17th Stufe (4W8 oder 4W12)</p>
      `,
      description_en: `
        <p>You point at one creature you can see within range, and the sound of a dolorous bell fills the air around it for a moment. The target must succeed on a Wisdom saving throw or take 1d8 necrotic damage. If the target is missing any of its hit points, it instead takes 1d12 necrotic damage.<p>

        <p> <b>At Higher Levels:</b> The spell’s damage increases by one die when you reach 5th level (2d8 or 2d12), 11th level (3d8 or 3d12), and 17th level (4d8 or 4d12).<p>
      `,
      school: 'necromancy',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 39,
      german: 'Verschonung der Toten',
      english: 'Spare the Dying',
      image: 'spareTheDying',
      level: 0,
      isCustom: false,
      classes: ['test', 'cleric'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du berührst eine lebende Kreatur mit 0 Trefferpunkten. Die Kreatur wird stabilisiert. Der Zauber hat keine Auswirkungen auf Untote oder Konstrukte.</p>
      `,
      description_en: `
        <p>You touch a living creature that has 0 hit points. The creature becomes stable. This spell has no effect on undead or constructs.</p>
      `,
      school: 'necromancy',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 40,
      german: 'Urtümliche Wildheit',
      english: 'Primal Savagery',
      image: 'primalSavagery',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 10, damageType: 'acid' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Deine Zähne oder Fingernägel werden zu scharfen Klauen, die du als Nahkampfwaffe verwenden kannst. Du führst einen Nahkampf-Zauberangriff gegen eine Kreatur deiner Wahl durch. Bei einem Treffer erleidet die Kreatur 1W10 Säureschaden.</p>
        <p><b>Auf höheren Graden:</b> Der Schaden des Zaubers erhöht sich um je 1W10 wenn du Stufe 5 (auf 2W10), Stufe 11 (auf 3W10) und Stufe 17 (auf 4W10) erreichst.</p>
      `,
      description_en: `
        <p>You channel primal magic to cause your teeth or fingernails to sharpen, ready to deliver a corrosive attack. Make a melee spell attack against one creature within 5 feet of you. On a hit, the target takes 1d10 acid damage.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th level (4d10).</p>
      `,
      school: 'transmutation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 41,
      german: 'Wasser formen',
      english: 'Shape Water',
      image: 'shapeWater',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid', 'sorcerer', 'wizard', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      durationType: 'hours',
      canRitual: false,
      isRitual: false,
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du wählst eine Wasserfläche, die du in Reichweite sehen kannst und die in einen Würfel von 5 Fußn passt. Du manipulierst es auf eine der folgenden Arten:</p>
        <ul>
          <li>Du bewegst das Wasser augenblicklich oder änderst es auf andere Weise, wie du es dir vorstellst, bis zu 5 Fuß in jede Richtung. Diese Bewegung hat nicht genug Kraft, um Schaden zu verursachen.</li>
          <li>Du bringst das Wasser dazu, sich zu einfachen Formen zu formen und sich auf deine Anweisung hin zu bewegen. Diese Veränderung hält 1 Stunde lang an.</li>
          <li>Du veränderst die Farbe oder Deckkraft des Wassers. Das Wasser muss immer auf dieselbe Weise verändert werden. Diese Veränderung hält 1 Stunde lang an.</li>
          <li>Du frierst das Wasser ein, vorausgesetzt, es befinden sich keine Lebewesen darin. Das Wasser taut in 1 Stunde wieder auf.</li>
        </ul>
        <p>Wenn du diesen Zauber mehrmals wirkst, kannst du nicht mehr als zwei seiner nicht sofortigen Effekte gleichzeitig aktiv haben, und du kannst einen solchen Effekt als Aktion abbrechen.</p>
      `,
      description_en: `
      <p>You choose an area of water that you can see within range and that fits within a 5-foot cube. You manipulate it in one of the following ways:</p>
      <ul>
        <li>You instantaneously move or otherwise change the flow of the water as you direct, up to 5 feet in any direction. This movement doesn’t have enough force to cause damage.</li>
        <li>You cause the water to form into simple shapes and animate at your direction. This change lasts for 1 hour.</li>
        <li>You change the water’s color or opacity. The water must be changed in the same way throughout. This change lasts for 1 hour.</li>
        <li>You freeze the water, provided that there are no creatures in it. The water unfreezes in 1 hour.</li>
      </ul>
      <p>If you cast this spell multiple times, you can have no more than two of its non-instantaneous effects active at a time, and you can dismiss such an effect as an action.</p>
      `,
      school: 'transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: true,
      areaOfEffectType: 'cube',
      diameter: 5,
    },
    {
      id: 42,
      german: 'Windböe',
      english: 'Gust',
      image: 'gust',
      level: 0,
      isCustom: false,
      classes: ['test', 'druid', 'sorcerer', 'wizard', 'artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'strength',
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du ergreifst die Luft und zwingst sie, einen der folgenden Effekte an einem Punkt in Reichweite, den du sehen kannst, zu erzeugen:</p>
        <ul>
          <li>Eine Kreatur mittlerer oder kleiner Größe, die du auswählst, muss einen Rettungswurf auf Stärke bestehen oder wird bis zu 5 Fuß von dir weggestoßen.</li>
          <li>Du erzeugst einen kleinen Luftstoß, der einen Gegenstand bewegen kann, der weder gehalten noch getragen wird und nicht mehr als 5 Pfund wiegt. Der Gegenstand wird bis zu 10 Fuß von dir weggeschoben. Er wird nicht mit so viel Kraft gestoßen, dass er Schaden anrichtet.</li>
          <li>Du erzeugst mit Luft einen harmlosen sensorischen Effekt, z.B. das Rascheln von Blättern, das Zuschlagen von Fensterläden durch den Wind oder das Kräuseln deiner Kleidung in einer Brise.</li>
        </ul>
      `,
      description_en: `
      <p>You seize the air and compel it to create one of the following effects at a point you can see within range:</p>
      <ul>
        <li>One Medium or smaller creature that you choose must succeed on a Strength saving throw or be pushed up to 5 feet away from you.</li>
        <li>You create a small blast of air capable of moving one object that is neither held nor carried and that weighs no more than 5 pounds. The object is pushed up to 10 feet away from you. It isn’t pushed with enough force to cause damage.</li>
        <li>You create a harmless sensory effect using air, such as causing leaves to rustle, wind to slam shutters shut, or your clothing to ripple in a breeze.</li>
      </ul>
      `,
      school: 'transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 43,
      german: 'Wort des Strahlens',
      english: 'Word of Radiance',
      image: 'wordOfRadiance',
      level: 0,
      isCustom: false,
      classes: ['test', 'cleric'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'constitution',
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'radiant' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
      <p>Du sprichst ein göttliches Wort aus, und ein brennendes Gleißen bricht aus dir heraus. Jede Kreatur deiner Wahl, welche du innerhalb der Reichweite sehen kannst, muss einen Konstitutionsrettungswurf ablegen oder erleidet 1W6 gleißenden Schaden.</p>
      <p><b>Auf höheren Graden:</b> Der Schaden des Zaubers erhöht sich um je 1W6 wenn du Stufe 5 (auf 2W6), Stufe 11 (auf 3W6) und Stufe 17 (auf 4W6) erreichst.</p>
      `,
      description_en: `
      <p>You utter a divine word, and burning radiance erupts from you. Each creature of your choice that you can see within range must succeed on a Constitution saving throw or take 1d6 radiant damage.</p>
      <p><b>At higher levels:</b> The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'evocation',
      isRanged: false,
      range: 0,
      hasAreaOfEffect: true,
      areaOfEffectType: 'circle',
      diameter: 10,
    },
    {
      id: 44,
      german: 'Zielsicherer Schlag',
      english: 'True Strike',
      image: 'trueStrike',
      level: 0,
      isCustom: false,
      classes: ['test', 'sorcerer', 'wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      canRitual: false,
      isRitual: false,
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du streckst deine Hand aus und deutest mit einem Finger auf das Ziel. Deine Magie gewährt dir einen kurzen Einblick in die Verteidigung des Ziels. In deinem nächsten Zug erhältst du Vorteil bei deinem ersten Angriffswurf gegen das Ziel, vorausgesetzt der Zauber ist nicht vorbei.</p>
      `,
      description_en: `
        <p>You extend your hand and point a finger at a target in range. Your magic grants you a brief insight into the target’s defenses. On your next turn, you gain advantage on your first attack roll against the target, provided that this spell hasn’t ended.</p>
      `,
      school: 'divination',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },

    /////////////
    // Level 1 //
    /////////////

    {
      id: 1003, // Der Tabelle entnehmen
      german: 'Befehl',
      english: 'Command',
      image: 'command', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'cleric', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'rounds', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'wisdom', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: 'prone' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Du sprichst einen Ein-Wort-Befehl zu einer Kreatur in Reichweite, die du sehen kannst. Das Ziel muss einen Rettungswurf auf Weisheit bestehen oder dem Befehl in seinem nächsten Zug folgen. Der Zauber hat keine Wirkung, wenn das Ziel untot ist, wenn es deine Sprache nicht versteht oder wenn dein Befehl ihm direkt schadet.</p>
          <p>Ein paar typische Befehle und ihre Effekte folgen. Du kannst auch einen anderen als den hier beschriebenen Befehl geben. Wenn du das tust, bestimmt der Spielleiter, wie sich das Ziel verhält. Wenn das Ziel deinen Befehl nicht befolgen kann, endet der Zauber.</p>
          <p><b>Annähern</b>: Das Ziel bewegt sich auf dem kürzesten und direktesten Weg auf dich zu und beendet seinen Zug, wenn es sich weniger als 1,5 Meter von dir entfernt.</p>
          <p><b>Abwerfen</b>: Das Ziel lässt alles fallen, was es in der Hand hält und beendet dann seinen Zug.</p>
          <p><b>Fliehen</b>: Das Ziel verbringt seinen Zug damit, sich auf dem schnellsten verfügbaren Weg von dir weg zu bewegen.</p>
          <p><b>Knien</b>: Das Ziel fällt auf den Boden und beendet dann seinen Zug.</p>
          <p><b>Halt</b>: Das Ziel bewegt sich nicht und führt keine Aktionen aus. Eine fliegende Kreatur bleibt in der Luft, sofern sie dazu in der Lage ist. Wenn sie sich bewegen muss, um in der Luft zu bleiben, fliegt sie die Mindestdistanz, die nötig ist, um in der Luft zu bleiben.</p>
          <p><b>Auf höheren Graden</b>: Wenn du diesen Zauber mit einem Zauberplatz des 2ten Grades oder höher wirkst, kannst du eine zusätzliche Kreatur für jeden Grad über dem ersten beeinflussen. Die Kreaturen müssen sich im Umkreis von 9 Metern befinden, wenn du sie als Ziel wählst.</p>
        `,
      description_en: `
          <p>You speak a one-word command to a creature you can see within range. The target must succeed on a Wisdom saving throw or follow the command on its next turn. The spell has no effect if the target is undead, if it doesn’t understand your language, or if your command is directly harmful to it. Some typical commands and their effects follow. You might issue a command other than one described here. If you do so, the DM determines how the target behaves. If the target can’t follow your command, the spell ends.</p>
          <p><b>Approach</b>. The target moves toward you by the shortest and most direct route, ending its turn if it moves within 5 feet of you.</p>
          <p><b>Drop</b>. The target drops whatever it is holding and then ends its turn.</p>
          <p><b>Flee</b>. The target spends its turn moving away from you by the fastest available means.</p>
          <p><b>Grovel</b>. The target falls prone and then ends its turn.</p>
          <p><b>Halt</b>. The target doesn’t move and takes no actions. A flying creature stays aloft, provided that it is able to do so. If it must move to stay aloft, it flies the minimum distance needed to remain in the air.</p>
          <p><b>At Higher Levels</b>. When you cast this spell using a spell slot of 2nd level or higher, you can affect one additional creature for each slot level above 1st. The creatures must be within 30 feet of each other when you target them.</p>
        `,
      school: 'enchantment', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 60, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 1008, // Der Tabelle entnehmen
      german: 'Donnerndes Niederstrecken',
      english: 'Thunderous Smite',
      image: 'thunderousSmite', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'bonus', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'strength', // alle attribute auf Englisch und klein
      doesDamage: true,
      damage: [{ diceNumber: 2, diceType: 6, damageType: 'lightning' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Das nächste Mal, wenn du eine Kreatur mit einem Waffenangriff triffst, ehe dieser Zauber endet, hallt deine Waffe mit Donner wider, und der Angriff fügt dem Ziel zusätzlich 2W6 Schallschaden zu. Wenn das Ziel eine Kreatur ist, muss sie außerdem einen Rettungswurf auf Stärke schaffen, um nicht 3 Meter von dir fortgestoßen zu werden und den Zustand liegend zu erleiden.</p>
        `,
      description_en: `
          <p>The first time you hit with a melee weapon attack during this spell’s duration, your weapon rings with thunder that is audible within 300 feet of you, and the attack deals an extra 2d6 thunder damage to the target. Additionally, if the target is a creature, it must succeed on a Strength saving throw or be pushed 10 feet away from you and knocked prone.</p>
        `,
      school: 'evocation', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 1014, // Der Tabelle entnehmen
      german: 'Erzwungenes Duell',
      english: 'Compelled Duel',
      image: 'compelledDuel', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'bonus', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'wisdom', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Du versuchst, eine Kreatur in ein Duell zu zwingen. Wähle eine Kreatur in Reichweite, die du sehen kannst. Sie muss einen Rettungswurf auf Weisheit machen. Bei einem misslungenen Rettungswurf wird die Kreatur von dir angezogen, gezwungen von deiner göttlichen Herausforderung. Für die Wirkungsdauer hat sie einen Nachteil bei Angriffswürfen gegen Kreaturen außer dir, und muss einen Rettungswurf auf Weisheit machen, immer wenn sie sich in einen Bereich bewegen will, der mehr als 9 Meter von dir entfernt ist, wenn der Rettungswurf erfolgreich ist, Schränkt der Zauber die Bewegung des Ziels für diesen Zug nicht ein.</p>
          <p>Der Zauber endet, wenn du eine andere Kreatur angreifst, wenn du einen Zauber wirkst, der auf eine feindliche Kreatur wirkt, die nicht das Ziel ist, wenn eine Kreatur, die mit dir verbündet ist, das Ziel verletzt oder einen schädigenden Zauber auf das Ziel wirkt, oder wenn du deinen Zug weiter als 9 Meter vom Ziel entfernt beendest.</p>
        `,
      description_en: `
          <p>You attempt to compel a creature into a duel. One creature that you can see within range must make a Wisdom saving throw. On a failed save, the creature is drawn to you, compelled by your divine demand. For the duration, it has disadvantage on attack rolls against creatures other than you, and must make a Wisdom saving throw each time it attempts to move to a space that is more than 30 feet away from you; if it succeeds on this saving throw, this spell doesn’t restrict the target’s movement for that turn.</p>
          <p>The spell ends if you attack any other creature, if you cast a spell that targets a hostile creature other than the target, if a creature friendly to you damages the target or casts a harmful spell on it, or if you end your turn more than 30 feet away from the target.</p>
        `,
      school: 'enchantment', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 30, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 1020,
      german: 'Gift und Krankheiten entdecken',
      english: 'Detect Poison and Disease',
      image: 'detectPoisonAndDisease',
      level: 1,
      cost: 'action',
      duration: 10,
      durationType: 'minutes',
      isCustom: false,
      classes: ['test', 'cleric', 'druid', 'paladin', 'ranger'],
      timeToCast: 0,
      canRitual: true,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de:
        'Während der Wirkungsdauer nimmst du die Gegenwart und die Position von Giften, giftigen Kreaturen und Krankheiten im Abstand von bis zu neun Metern von dir wahr. Du kannst auch die Art des Gifts, der giftigen Kreatur oder der Krankheit bestimmen. Dieser Zauber durchdringt die meisten Barrieren, wird aber von 1 Fußn Stein, 2,5 Zentimetern gewöhnlichem Metall, dünnem Bleiblech sowie von einem Meter Holz oder Erde blockiert.',
      description_en:
        'For the duration, you can sense the presence and location of poisons, poisonous creatures, and diseases within 30 feet of you. You also identify the kind of poison, poisonous creature, or disease in each case. The spell can penetrate most barriers, but it is blocked by 1 foot of stone, 1 inch of common metal, a thin sheet of lead, or 3 feet of wood or dirt.',
      school: 'divination',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 1022, // Der Tabelle entnehmen
      german: 'Gutes und Böses entdecken',
      english: 'Detect Evil and Good',
      image: 'detectEvilAndGood', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'cleric', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Für die Dauer des Zaubers weißt du, ob sich im Umkreis von 9 Metern ein Abnormaler, ein Himmlischer, ein Elementarer, ein Fee, ein Unhold oder ein Untoter aufhält und wo sich die Kreatur befindet. Ebenso weißt du, ob sich im Umkreis von 9 Metern ein magisch geweihter oder entweihter Ort oder Gegenstand befindet.</p>
          <p>Der Zauber kann die meisten Barrieren durchdringen, wird aber durch 30 Zentimeter Stein, 2,5 Zentimeter gewöhnliches Metall, eine dünne Bleiplatte oder 1 Meter Holz oder Erde blockiert.</p>
        `,
      description_en: `
          <p>For the duration, you know if there is an aberration, celestial, elemental, fey, fiend, or undead within 30 feet of you, as well as where the creature is located. Similarly, you know if there is a place or object within 30 feet of you that has been magically consecrated or desecrated.</p>
          <p>The spell can penetrate most barriers, but it is blocked by 1 foot of stone, 1 inch of common metal, a thin sheet of lead, or 3 feet of wood or dirt.</p>
        `,
      school: 'divination', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: true,
      areaOfEffectType: 'sphere', // circle | cone | cube | cylinder | line | sphere
      diameter: 30,
    },
    {
      id: 1023, // Der Tabelle entnehmen
      german: 'Göttliche Gunst',
      english: 'Divine Favor',
      image: 'divineFavor', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'bonus', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 4, damageType: 'radiant' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Dein Gebet verleiht dir eine göttliche Ausstrahlung. Bis der Zauber endet, verursachen deine Waffenangriffe bei einem Treffer zusätzlich 1W4 Strahlungsschaden.</p>
        `,
      description_en: `
          <p>Your prayer empowers you with divine radiance. Until the spell ends, your weapon attacks deal an extra 1d4 radiant damage on a hit.</p>
        `,
      school: 'evocation', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 1024,
      german: 'Heilendes Wort',
      english: 'Healing Word',
      image: 'healingWord',
      isCustom: false,
      classes: ['test', 'bard', 'cleric', 'druid'],
      level: 1,
      cost: 'bonus action',
      duration: 0,
      durationType: 'rounds',
      timeToCast: 0,
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: true,
      heal: { diceNumber: 1, diceType: 4, additionalHeal: 4 },
      description_de:
        'Eine Kreatur deiner Wahl in Reichweite, die du sehen kannst, gewinnt Trefferpunkte in Höhe von 1W4 + deinem Zauberwirken-Attributsmodifikator zurück. Dieser Zauber wirkt nicht auf Untote oder Konstrukte. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt die Heilung für jeden Grad über dem 1. um 1W4.',
      description_en:
        'A creature of your choice that you can see within range regains hit points equal to 1d4 + your spellcasting ability modifier. This spell has no effect on undead or constructs. At higher levels: When you cast this spell using a spell slot of 2nd level or higher, the healing increases by 1d4 for each slot level above 1st.',
      school: 'evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 1025,
      german: 'Heiligtum',
      english: 'Sanctuary',
      image: 'sanctuary',
      level: 1,
      isCustom: false,
      classes: ['test', 'cleric'],
      timeToCast: 0,
      cost: 'bonus action',
      duration: 1,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de:
        'Du schützt eine Kreatur in Reichweite vor Angriffen. Während der Wirkungsdauer muss jede Kreatur, die bei einem Angriff oder schädlichen Zauber die geschützte Kreatur als Ziel hat, zuerst einen Weisheitsrettungswurf bestehen. Scheitert der Wurf, muss die Kreatur ein neues Ziel wählen, oder sie verliert den Angriff oder Zauber. Dieser Zauber schützt die entsprechende Kreatur nicht vor Flächeneffekten wie der Explosion eines Feuerballs. Greift die geschützte Kreatur an oder wirkt sie einen Zauber auf eine feindliche Kreatur, endet der Effekt dieses Zaubers.',
      description_en:
        'You ward a creature within range against attack. Until the spell ends, any creature who targets the warded creature with an attack or a harmful spell must first make a Wisdom saving throw. On a failed save, the creature must choose a new target or lose the attack or spell. This spell doesn’t protect the warded creature from area effects, such as the explosion of a fireball. If the warded creature makes an attack or casts a spell that affects an enemy creature, this spell ends.',
      school: 'abjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 1026,
      german: 'Heldenmut',
      english: 'Heroism',
      image: 'heroism',
      level: 1,
      cost: 'action',
      duration: 1,
      durationType: 'minutes',
      isCustom: false,
      classes: ['test', 'bard', 'paladin'],
      timeToCast: 0,
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de:
        'Du berührst eine bereitwillige Kreatur und erfüllst sie mit Tapferkeit. Bis der Zauber endet, kann die Kreatur nicht verängstigt werden, und sie erhält zu Beginn jedes ihrer Züge temporäre Trefferpunkte in Höhe deines Zauberwirken-Attributsmodifikators. Wenn der Zauber endet, verliert das Ziel alle verbleibenden temporären Trefferpunkte dieses Zaubers. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, kannst du für jeden Grad über dem 1. eine zusätzliche Kreatur als Ziel wählen.',
      description_en:
        'A willing creature you touch is imbued with bravery. Until the spell ends, the creature is immune to being frightened and gains temporary hit points equal to your spellcasting ability modifier at the start of each of its turns. When the spell ends, the target loses any remaining temporary hit points from this spell. At higher levels: When you cast this spell using a spell slot of 2nd level or higher, you can target one additional creature for each slot level above 1st.',
      school: 'enchantment',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 1034,
      german: 'Lenkendes Geschoss',
      english: 'Guiding Bolt',
      image: 'guidingBolt',
      level: 1,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      isCustom: false,
      classes: ['test', 'cleric'],
      timeToCast: 0,
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 4, diceType: 6, damageType: 'radiant' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de:
        'Ein Lichtblitz schießt auf eine Kreatur deiner Wahl in Reichweite zu. Führe einen Fernkampf-Zauberangriff gegen das Ziel aus. Bei einem Erfolg erleidet das Ziel 4W6 gleißenden Schaden. Dank des mystischen dämmrigen Lichts, das auf dem Ziel glitzert, ist der nächste Angriffswurf gegen das Ziel vor Ende deines nächsten Zugs im Vorteil. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt der Schaden für jeden Grad über dem 1. um 1W6.',
      description_en:
        'A flash of light streaks toward a creature of your choice within range. Make a ranged spell attack against the target. On a hit, the target takes 4d6 radiant damage, and the next attack roll made against this target before the end of your next turn has advantage, thanks to the mystical dim light glittering on the target until then. At higher levels: When you cast this spell using a spell slot of 2nd level or higher, the damage increases by 1d6 for each slot level above 1st.',
      school: 'evocation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 1035,
      german: 'Magie entdecken',
      english: 'Detact Magic',
      image: 'detectMagic',
      level: 1,
      cost: 'action',
      duration: 10,
      durationType: 'minutes',
      isCustom: false,
      classes: [
        'test',
        'bard',
        'cleric',
        'druid',
        'paladin',
        'ranger',
        'sorcerer',
        'wizard',
      ],
      timeToCast: 0,
      canRitual: true,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de:
        'Während der Wirkungsdauer nimmst du die Gegenwart von Magie im Abstand von bis zu 30 Fuß von dir wahr. Wenn du auf diese Weise Magie wahrnimmst, kannst du deine Aktion verwenden, um schwache Auren um sichtbare magische Kreaturen oder Objekte sowie ihre magische Schule zu erkennen, falls vorhanden. Dieser Zauber durchdringt die meisten Barrieren, wird aber von 30 Zentimeter Stein, 2,5 Zentimetern gewöhnlichem Metall, dünnem Bleiblech sowie von einem Meter Holz oder Erde blockiert.',
      description_en:
        'For the duration, you sense the presence of magic within 30 feet of you. If you sense magic in this way, you can use your action to see a faint aura around any visible creature or object in the area that bears magic, and you learn its school of magic, if any. The spell can penetrate most barriers, but it is blocked by 1 foot of stone, 1 inch of common metal, a thin sheet of lead, or 3 feet of wood or dirt.',
      school: 'divination',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 1039, // Der Tabelle entnehmen
      german: 'Nahrung und Wasser reinigen',
      english: 'Purify Food and Drink',
      image: 'purifyFoodAndDrink', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'druid', 'cleric', 'paladin', 'artificer'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: true, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Alle nichtmagischen Nahrungsmittel und Getränke in einer Sphäre mit einem Radius von 1,5 Metern, zentriert um einen Punkt deiner Wahl in Reichweite, werden gereinigt und von Giften und Krankheiten befreit.</p>
        `,
      description_en: `
          <p>All nonmagical food and drink within a 5-foot-radius sphere centered on a point of your choice within range is purified and rendered free of poison and disease.</p>
        `,

      school: 'transmutation', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 10, // 5 wenn keine Range
      hasAreaOfEffect: true,
      areaOfEffectType: 'sphere', // circle | cone | cube | cylinder | line | sphere
      diameter: 5,
    },
    {
      id: 1045, // Der Tabelle entnehmen
      german: 'Schild des Glaubens',
      english: 'Shield of Faith',
      image: 'shieldOfFaith', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'cleric', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'bonus', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Ein Schimmerndes Feld erscheint und umhüllt eine Kreatur deiner Wahl in Reichweite. Es gewährt ihr für die Wirkungsdauer einen Bonus von +2 auf RK.</p>
        `,
      description_en: `
          <p>A shimmering field appears and surrounds a creature of your choice within range, granting it a +2 bonus to AC for the duration.</p>
        `,
      school: 'abjuration', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 60, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 1048, // Der Tabelle entnehmen
      german: 'Schutz vor Gut und Böse',
      english: 'Protection from Evil and Good',
      image: 'protectionFromEvilAndGood', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'warlock', 'cleric', 'wizard', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Bis der Zauber endet, wird eine bereitwillige Kreatur, die du berührst, vor bestimmten Arten von Kreaturen geschützt: Aberrationen, himmlische Wesen, Elementare, Feen, Unholde und Untote. </p>
          <p>Der Schutz bietet mehrere Vorteile: Kreaturen dieser Art haben einen Nachteil auf Angriffswürfe gegen das Ziel. Das Ziel kann außerdem nicht von ihnen bezaubert, verängstigt oder durch sie besessen werden. Wenn das Ziel bereits verzaubert, verängstigt oder von einer solchen Kreatur besessen ist, hat das Ziel Vorteil bei jedem neuen Rettungswurf gegen den relevanten Effekt.</p>
        `,
      description_en: `
          <p>Until the spell ends, one willing creature you touch is protected against certain types of creatures: aberrations, celestials, elementals, fey, fiends, and undead.</p>
          <p>The protection grants several benefits. Creatures of those types have disadvantage on attack rolls against the target. The target also can't be charmed, frightened, or possessed by them. If the target is already charmed, frightened, or possessed by such a creature, the target has advantage on any new saving throw against the relevant effect.</p>
        `,
      school: 'abjuration', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 1049,
      german: 'Segnen',
      english: 'Bless',
      image: 'bless',
      level: 1,
      cost: 'action',
      duration: 1,
      durationType: 'minutes',
      isCustom: false,
      classes: ['test', 'cleric', 'paladin'],
      timeToCast: 0,
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de:
        'Du segnest bis zu drei Kreaturen deiner Wahl in Reichweite. Wenn ein Ziel während der Wirkungsdauer einen Angriffs- oder Rettungswurf ausführt, darf es mit einem W4 würfeln und das Würfelergebnis zu seinem Angriffs- oder Rettungswurf addieren. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, kannst du für jeden Grad über dem 1. eine zusätzliche Kreatur als Ziel wählen.',
      description_en:
        'You bless up to three creatures of your choice within range. Whenever a target makes an attack roll or a saving throw before the spell ends, the target can roll a d4 and add the number rolled to the attack roll or saving throw. At higher levels: When you cast this spell using a spell slot of 2nd level or higher, you can target one additional creature for each slot level above 1st.',
      school: 'enchantment',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 1051, // Der Tabelle entnehmen
      german: 'Sengendes Niederstrecken',
      english: 'Searing Smite',
      image: 'searingSmite', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'bonus', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'constitution', // alle attribute auf Englisch und klein
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'fire' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Das nächste Mal, wenn du innerhalb der Wirkungsdauer des Zaubers eine Kreatur mit einer Nahkampfwaffe triffst, blitzt deine Waffe mit weißglühender Intensität auf.</p>
          <p>Der Angriff fügt dem Ziel zusätzlich 1W6 Feuerschaden zu und lässt es in Flammen aufgehen.</p>
          <p>Zu Beginn eines jeden seiner Züge, bis der Zauber endet, muss das Ziel einen Konstitutionsrettungswurf ablegen. Misslingt er, erleidet es 1W6 Feuerschaden. Bei einem erfolgreichen Rettungswurf endet der Zauber.</p>
          <p>Wenn das Ziel oder eine Kreatur im Umkreis von 1,5m von ihm eine Aktion verwendet, um die Flammen zu ersticken, oder ein anderer Effekt das Feuer löscht (beispielweise wenn die betroffene Kreatur unter Wasser getaucht wird oder es regnet), endet der Zauber.</p>
          <p><b>Auf höheren Stufen:</b> Wenn du diesen Spruch mit einem Zauberplatz des 2. oder eines höheren Grades wirkst, steigt der anfängliche Bonusschaden beim Angriff für jeden Grad über den 1. hinaus um 1W6.</p>
        `,
      description_en: `
          <p>The next time you hit a creature with a melee weapon attack during the spell’s duration, your weapon flares with white-hot intensity, and the attack deals an extra 1d6 fire damage to the target and causes the target to ignite in flames.</p>
          <p>At the start of each of its turns until the spell ends, the target must make a Constitution saving throw. On a failed save, it takes 1d6 fire damage. On a successful save, the spells ends. If the target or a creature within 5 feet of it uses an action to put out the flames, or if some other effect douses the flames (such as the target being submerged in water), the spell ends.</p>
          <p><b>At higher levels:</b> When you cast this spell using a spell slot of 2nd level or higher, the initial extra damage dealt by the attack increases by 1d6 for each slot.</p>
        `,
      school: 'evocation', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 1062, // Der Tabelle entnehmen
      german: 'Verderben',
      english: 'Bane',
      image: 'bane', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'bard', 'warlock', 'wizard'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'charisma', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Bis zu drei Kreaturen deiner Wahl in Reichweite, die du sehen kannst, müssen Rettungswürfe auf Charisma machen. Immer wenn ein Ziel, das seinen Rettungswurf nicht geschafft hat, einen Angriffs- oder Rettungswurf macht bis der Zauber endet, muss es einen W4 werfen und das Ergebnis vom Angriffs- oder Rettungswurf abziehen.</p>
          <p><b>Auf höheren Stufen:</b> Wenn du diesen Zauber mit einem Zauberplatz des 2. Grades oder höher wirkst, dann kannst du den Zauber für jeden Zauberplatzgrad über dem ersten auf eine zusätzliche Kreatur wirken.</p>
        `,
      description_en: `
          <p>Up to three creatures of your choice that you can see within range must make Charisma saving throws. Whenever a target that fails this saving throw makes an attack roll or a saving throw before the spell ends, the target must roll a d4 and subtract the number rolled from the attack roll or saving throw.</p>
          <p><b>At higher levels:</b> When you cast this spell using a spell slot of 2nd level or higher, you can target one additional creature for each slot level above 1st.</p>
        `,
      school: 'enchantment', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 30, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 1067,
      german: 'Wunden Heilen',
      english: 'Cure Wounds',
      image: 'cureWounds',
      level: 1,
      cost: 'action',
      duration: 0,
      durationType: 'rounds',
      isCustom: false,
      classes: ['test', 'bard', 'cleric', 'druid', 'paladin', 'ranger'],
      timeToCast: 0,
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }],
      doesHeal: true,
      heal: { diceNumber: 1, diceType: 8, additionalHeal: 4 },
      description_de:
        'Eine Kreatur, die du berührst, gewinnt Trefferpunkte in Höhe von 1W8 + deinem Attributsmodifikator im Zauberwirken zurück. Dieser Zauber wirkt nicht auf Untote oder Konstrukte. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt die Heilung für jeden Grad über dem 1. um 1W8.',
      description_en:
        'A creature you touch regains a number of hit points equal to 1d8 + your spellcasting ability modifier. This spell has no effect on undead or constructs. At higher levels: When you cast this spell using a spell slot of 2nd level or higher, the healing increases by 1d8 for each slot level above 1st.',
      school: 'evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 1068,
      german: 'Wunden verursachen',
      english: 'Inflict Wounds',
      image: 'inflictWounds',
      level: 1,
      cost: 'action',
      isCustom: false,
      classes: ['test', 'cleric'],
      duration: 0,
      durationType: 'rounds',
      timeToCast: 0,
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 3, diceType: 10, damageType: 'necrotic' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de:
        'Mach einen Nahkampf-Zauberangriff gegen eine Kreatur deiner Wahl. Bei einem Erfolg erleidet das Ziel 3W10 Nekrotischen Schaden. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt der Schaden für jeden Grad über dem 1. um 1W10.',
      description_en:
        'Make a melee spell attack against a creature you can reach. On a hit, the target takes 3d10 necrotic damage. At higher levels: When you cast this spell using a spell slot of 2nd level or higher, the damage increases by 1d10 for each slot level above 1st.',
      school: 'necromancy',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 1069, // Der Tabelle entnehmen
      german: 'Zeichen des Jägers',
      english: "Hunter's Mark",
      image: 'huntersMark', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'ranger'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'bonus', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'hour', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Du wählst eine Kreatur in Reichweite aus, die du sehen kannst, und markierst sie auf mystische Art als deine Beute. Bis der Zauber endet, fügst du dem Ziel jedes Mal 1W6 Schaden zu, wenn du es mit einem Waffenangriff triffst, und du hast Vorteil bei Würfen auf Wahrnehmung oder Überleben, wenn du das Ziel finden willst. Wenn das Ziel auf 0 Trefferpunkte fällt, ehe der Zauber endet, kannst du in einem späteren Zug eine Bonusaktion verwenden, um eine neue Kreatur zu markieren.</p>
          <p><b>Auf höheren Stufen:</b> Wenn du diesen Zauber mit einem Zauberplatz des 3. oder 4. Grades wirkst, kannst du deine Konzentration für bis zu 8 Stunden aufrechterhalten. Wenn du diesen Zauber mit einem Zauberplatz des 5. Grades oder höher wirkst, kannst du deine Konzentration für bis zu 24 Stunden aufrechterhalten.</p>
        `,
      description_en: `
          <p>You choose a creature you can see within range and mystically mark it as your quarry. Until the spell ends, you deal an extra 1d6 damage to the target whenever you hit it with a weapon attack, and you have advantage on any Wisdom (Perception) or Wisdom (Survival) check you make to find it.</p>
          <p>If the target drops to 0 hit points before this spell ends, you can use a bonus action on a subsequent turn of yours to mark a new creature.</p>
          <p><b>At higher levels:</b> When you cast this spell using a spell slot of 3rd or 4th level, you can maintain your concentration on the spell for up to 8 hours. When you use a spell slot of 5th level or higher, you can maintain your concentration on the spell for up to 24 hours.</p>
        `,
      school: 'divination', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 90, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 1072, // Der Tabelle entnehmen
      german: 'Zorniges Niederstrecken',
      english: 'Wrathful Smite',
      image: 'wrathfulSmite', //Englischer name in lowerCamelCase
      level: 1,
      isCustom: false, // immer false
      classes: ['test', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'bonus', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'wisdom', // alle attribute auf Englisch und klein
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'psychic' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Das nächste Mal, wenn du eine Kreatur mit einem Nahkampfwaffenangriff triffst, ehe dieser Zauber endet, fügt dein Angriff zusätzlich 1W6 psychischen Schaden zu. Wenn das Ziel außerdem eine Kreatur ist, muss sie einen Rettungswurf auf Weisheit bestehen, sonst ist sie bis zum Ende des Zaubers Verängstigt. Als Aktion kann eine Kreatur einen Weisheitswurf gegen deinen Zauberrettungswurf-SG ablegen, um ihren Willen zu stählen und diesen Zauber zu beenden.</p>
        `,
      description_en: `
          <p>The next time you hit with a melee weapon attack during this spell’s duration, your attack deals an extra 1d6 psychic damage. Additionally, if the target is a creature, it must make a Wisdom saving throw or be frightened of you until the spell ends. As an action, the creature can make a Wisdom check against your spell save DC to steel its resolve and end this spell.</p>
        `,
      school: 'evocation', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },

    /////////////
    // Level 2 //
    /////////////

    {
      id: 2005, // Der Tabelle entnehmen
      german: 'Beistand',
      english: 'Aid',
      image: 'aid', //Englischer name in lowerCamelCase
      level: 2,
      isCustom: false, // immer false
      classes: ['test', 'cleric', 'paladin', 'artificer'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 8, // gerade unwichtig, einfach 0 eintragen
      durationType: 'hours', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Dein Zauber stärkt die Entschlossenheit und Zähigkeit deiner Verbündeten. Wähle bis zu drei Kreaturen in Reichweite. Die maximalen und aktuellen Trefferpunkte aller Ziele steigen für die Wirkungsdauer um 5.</p>
          <p><b>Auf höheren Stufen:</b> Wenn du diesen Zauber mit einem Zauberplatz des 3. Grades oder höher wirkst, dann steigen die Trefferpunkte des Ziels um zusätzlich 5 für jeden Zauberplatz-Grad über dem zweiten.</p>
        `,
      description_en: `
          <p>Your spell bolsters your allies with toughness and resolve. Choose up to three creatures within range. Each target’s hit point maximum and current hit points increase by 5 for the duration.</p>
          <p><b>At higher levels:</b> When you cast this spell using a spell slot of 3rd level or higher, a target’s hit points increase by an additional 5 for each slot level above 2nd.</p>
        `,
      school: 'abjuration', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 30, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 2007, // Der Tabelle entnehmen
      german: 'Brandmarkendes Niederstrecken',
      english: 'Branding Smite',
      image: 'brandingSmite', //Englischer name in lowerCamelCase
      level: 2,
      isCustom: false, // immer false
      classes: ['test', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'bonus', // action | bonus | reaction
      duration: 1, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 6, damageType: 'radiant' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Wenn du das nächste Mal eine Kreatur mit einem Waffenangriff triffst, bevor dieser Zauber endet, schimmert die Waffe beim Schlag in astralem Glanz. Der Angriff fügt dem Ziel zusätzlich 2W6 gleißender Schaden zu, es wird sichtbar, falls es unsichtbar ist, und das Ziel wirft in einem Radius von 1,5 Metern ein schwaches Licht ab und kann nicht unsichtbar werden, bis der Zauber endet.</p>
          <p><b>Auf höheren Stufen:</b> Wenn du diesen Zauber mit einem Zauberplatz des 3. Grades oder höher wirkst, erhöht sich der zusätzliche Schaden um 1W6 für jeden Grad des Zauberplatzes über dem 2.</p>
        `,
      description_en: `
          <p>The next time you hit a creature with a weapon attack before this spell ends, the weapon gleams with astral radiance as you strike. The attack deals an extra 2d6 radiant damage to the target, which becomes visible if it is invisible, and the target sheds dim light in a 5-foot radius and can’t become invisible until the spell ends.</p>
          <p><b>At higher levels:</b> When you cast this spell using a spell slot of 3rd level or higher, the extra damage increases by 1d6 for each slot level above 2nd.</p>
        `,
      school: 'evocation', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 2025, // Der Tabelle entnehmen
      german: 'Gegenstand aufspüren',
      english: 'Locate Object',
      image: 'locateObject', //Englischer name in lowerCamelCase
      level: 2,
      isCustom: false, // immer false
      classes: [
        'test',
        'bard',
        'druid',
        'cleric',
        'wizard',
        'paladin',
        'ranger',
      ], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 10, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Beschreibe oder benenne ein Objekt, das dir bekannt ist. Du spürst die Richtung, in der sich das Objekt befindet, solange es sich nicht weiter als 300 Meter von dir entfernt befindet. Wenn das Objekt in Bewegung ist, kennst du die Richtung seiner Bewegung.</p>
          <p>Der Zauber kann ein bestimmtes, dir bekanntes Objekt lokalisieren, wenn du es mindestens einmal aus der Nähe - innerhalb von 9 Metern - gesehen hast. Alternativ kann der Zauber den nächstgelegenen Gegenstand einer bestimmten Art lokalisieren, z.B. eine bestimmte Art von Kleidung, Schmuck, Möbeln, Werkzeug oder Waffen.</p>
          <p>Dieser Zauber kann einen Gegenstand nicht lokalisieren, wenn eine dünne Schicht Blei den direkten Weg zwischen dir und dem Gegenstand versperrt, selbst wenn es sich um ein dünnes Blatt handelt.</p>
        `,
      description_en: `
          <p>Describe or name an object that is familiar to you. You sense the direction to the object’s location, as long as that object is within 1,000 feet of you. If the object is in motion, you know the direction of its movement.</p>
          <p>The spell can locate a specific object known to you, as long as you have seen it up close – within 30 feet – at least once. Alternatively, the spell can locate the nearest object of a particular kind, such as a certain kind of apparel, jewelry, furniture, tool, or weapon.</p>
          <p>This spell can’t locate an object if any thickness of lead, even a thin sheet, blocks a direct path between you and the object.</p>
        `,
      school: 'divination', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 2032, // Der Tabelle entnehmen
      german: 'Magische Waffe',
      english: 'Magic Weapon',
      image: 'magicWeapon', //Englischer name in lowerCamelCase
      level: 2,
      isCustom: false, // immer false
      classes: ['test', 'wizard', 'paladin', 'artificer'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'bonus', // action | bonus | reaction
      duration: 1, // gerade unwichtig, einfach 0 eintragen
      durationType: 'hours', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Du berührst eine nichtmagische Waffe. Bis der Zauber endet, wird diese Waffe zu einer magischen Waffe mit einem Bonus von +1 auf Angriffs- und Schadenswürfe.</p>
          <p><b>Auf höheren Stufen:</b> Wenn du diesen Zauber mit einem Zauberplatz des 4. Grades oder höher wirkst, erhöht sich der Bonus auf +2. Wenn du einen Zauberplatz des 6. Grades oder höher verwendest, erhöht sich der Bonus auf +3.</p>
        `,
      description_en: `
          <p>You touch a nonmagical weapon. Until the spell ends, that weapon becomes a magic weapon with a +1 bonus to attack rolls and damage rolls.</p>
          <p><b>At higher levels:</b> When you cast this spell using a spell slot of 4th level or higher, the bonus increases to +2. When you use a spell slot of 6th level or higher, the bonus increases to +3.</p>
        `,
      school: 'transmutation', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 2038, // Der Tabelle entnehmen
      german: 'Nebelschritt',
      english: 'Misty Step',
      image: 'mistyStep', //Englischer name in lowerCamelCase
      level: 2,
      isCustom: false, // immer false
      classes: ['test', 'warlock', 'wizard', 'sorcerer'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'bonus', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: '', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Du bist kurz von silbrigem Nebel umgeben und teleportierst dich bis zu 9 Meter weit an einen freien Platz, den du sehen kannst.</p>
        `,
      description_en: `
          <p>Briefly surrounded by silvery mist, you teleport up to 30 feet to an unoccupied space that you can see.</p>
        `,
      school: 'conjuration', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 30, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 2040, // Der Tabelle entnehmen
      german: 'Person festhalten',
      english: 'Hold Person',
      image: 'holdPerson', //Englischer name in lowerCamelCase
      level: 2,
      isCustom: false, // immer false
      classes: [
        'test',
        'bard',
        'druid',
        'warlock',
        'cleric',
        'wizard',
        'sorcerer',
      ], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'wisdom', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Wähle einen Humanoiden in Reichweite, den du sehen kannst. Das Ziel muss einen Rettungswurf auf Weisheit machen, um nicht für die Wirkungsdauer gelähmt zu werden. Zu Beginn eines jeden seiner Züge, kann das Ziel einen weiteren Rettungswurf auf Weisheit machen. Bei einem Erfolg endet der Zauber für das Ziel.</p>
          <p><b>Auf höheren Stufen:</b> Wenn du diesen Zauber mit einem Zauberplatz des 3. Grades oder höher wirkst, dann kannst du den Zauber für jeden Zauberplatz-Grad über dem zweiten auf eine zusätzliche humanoide Kreatur wirken. Die Kreaturen dürfen nicht weiter als 9 Meter voneinander entfernt sein, wenn du den Zauber auf sie wirkst.</p>
        `,
      description_en: `
          <p>Choose a humanoid that you can see within range. The target must succeed on a Wisdom saving throw or be paralyzed for the duration. At the end of each of its turns, the target can make another Wisdom saving throw. On a success, the spell ends on the target.</p>
          <p><b>At higher levels:</b> When you cast this spell using a spell slot of 3rd level or higher, you can target one additional humanoid for each slot level above 2nd. The humanoids must be within 30 feet of each other when you target them.</p>
        `,
      school: 'enchantment', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 60, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 2042, // Der Tabelle entnehmen
      german: 'Reittier finden',
      english: 'Find Steed',
      image: 'findSteed', //Englischer name in lowerCamelCase
      level: 2,
      isCustom: false, // immer false
      classes: ['test', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: '10 minutes', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: '', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },

      description_de: `
          <p>Du beschwörst einen Geist, der die Form eines ungewöhnlich intelligenten, starken und treuen Reittiers annimmt und eine dauerhafte Bindung mit ihm eingeht. Das Reittier erscheint an einem unbesetzten Ort in Reichweite und nimmt die Form eines Pferdes deiner Wahl an, z. B. eines Haudegens, eines Ponys, eines Kamels, eines Elchs oder eines Mastiffs. (Dein Spielleiter kann auch erlauben, andere Tiere als Reittiere zu beschwören.) Das Reittier hat die gleichen Eigenschaften wie die gewählte Form, ist aber ein Himmels-, Feen- oder Ungeheuerwesen (nach deiner Wahl) statt seines normalen Typs. Wenn dein Reittier eine Intelligenz von 5 oder weniger hat, wird seine Intelligenz auf 6 erhöht und es erhält die Fähigkeit, eine Sprache deiner Wahl zu verstehen, die du sprichst.</p>
          <p>Dein Reittier dient dir, sowohl im Kampf als auch in der Freizeit, und du hast eine instinktive Verbindung zu ihm, die es dir ermöglicht, als nahtlose Einheit zu kämpfen. Während du auf deinem Reittier sitzt, kannst du jeden Zauber, der nur auf dich zielt, auch auf dein Reittier wirken.</p>
          <p>Wenn das Reittier auf 0 Trefferpunkte sinkt, verschwindet es und hinterlässt keine physische Form. Du kannst dein Reittier auch jederzeit mit einer Aktion entlassen, die es verschwinden lässt. In beiden Fällen beschwörst du mit diesem Zauber dasselbe Reittier erneut, wobei es seine maximale Anzahl an Trefferpunkten wiedererlangt.</p>
          <p>Solange sich dein Reittier in einem Umkreis von 1,6 Kilometern befindet, kannst du telepathisch mit ihm kommunizieren.</p>
          <p>Du kannst nicht mehr als ein durch diesen Zauber gebundenes Reittier gleichzeitig haben. Als Aktion kannst du das Reittier jederzeit aus der Bindung lösen, so dass es verschwindet.</p>
        `,
      description_en: `
          <p>You summon a spirit that assumes the form of an unusually intelligent, strong, and loyal steed, creating a long-lasting bond with it. Appearing in an unoccupied space within range, the steed takes on a form that you choose: a warhorse, a pony, a camel, an elk, or a mastiff. (Your DM might allow other animals to be summoned as steeds.) The steed has the statistics of the chosen form, though it is a celestial, fey, or fiend (your choice) instead of its normal type. Additionally, if your steed has an Intelligence of 5 or less, its Intelligence becomes 6, and it gains the ability to understand one language of your choice that you speak.</p>
          <p>Your steed serves you as a mount, both in combat and out, and you have an instinctive bond with it that allows you to fight as a seamless unit. While mounted on your steed, you can make any spell you cast that targets only you also target your steed.</p>
          <p>When the steed drops to 0 hit points, it disappears, leaving behind no physical form. You can also dismiss your steed at any time as an action, causing it to disappear. In either case, casting this spell again summons the same steed, restored to its hit point maximum.</p>
          <p>While your steed is within 1 mile of you, you can communicate with each other telepathically. You can’t have more than one steed bonded by this spell at a time. As an action, you can release the steed from its bond at any time, causing it to disappear.</p>
        `,
      school: 'conjuration', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 30, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 2046, // Der Tabelle entnehmen
      german: 'Schutz vor Gift',
      english: 'Protection from Poison',
      image: 'protectionFromPoison', //Englischer name in lowerCamelCase
      level: 2,
      isCustom: false, // immer false
      classes: ['test', 'druid', 'cleric', 'paladin', 'ranger', 'artificer'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'hours', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Du berührst eine Kreatur. Wenn sie vergiftet ist, neutralisierst du das Gift. Wenn das Ziel von mehr als einem Gift befallen ist, neutralisierst du ein Gift, von dem du weißt, dass es vorhanden ist, oder du neutralisierst ein zufälliges. Während der Dauer des Zaubers hat das Ziel Vorteil bei Rettungswürfen gegen Vergiftungen und ist resistent gegen Giftschaden.</p>
        `,
      description_en: `
          <p>You touch a creature. If it is poisoned, you neutralize the poison. If more than one poison afflicts the target, you neutralize one poison that you know is present, or you neutralize one at random.</p>
          <p>For the duration, the target has advantage on saving throws against being poisoned, and it has resistance to poison damage.</p>
        `,
      school: 'abjuration', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 2048, // Der Tabelle entnehmen
      german: 'Schwache Genesung',
      english: 'Lesser Restoration',
      image: 'lesserRestoration', //Englischer name in lowerCamelCase
      level: 2,
      isCustom: false, // immer false
      classes: [
        'test',
        'bard',
        'druid',
        'cleric',
        'paladin',
        'ranger',
        'artificer',
      ], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 0, // gerade unwichtig, einfach 0 eintragen
      durationType: 'rounds', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      savingThrowAttribute: '', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: true,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Du berührst eine Kreatur und kannst entweder eine Krankheit beenden, an der sie leidet, oder einen Zustand, den sie erlitten hat. Dieser Zustand kann blind, gelähmt, taub oder vergiftet sein.</p>
        `,
      description_en: `
          <p>You touch a creature and can end either one disease or one condition afflicting it. The condition can be blinded, deafened, paralyzed, or poisoned.</p>
        `,
      school: 'abjuration', // alles klein geschrieben
      isRanged: false, // ob es mehr, als 5 Fuß Reichweite hat
      range: 5, // 5 wenn keine Range
      hasAreaOfEffect: false,
      areaOfEffectType: '', // circle | cone | cube | cylinder | line | sphere
      diameter: 0,
    },
    {
      id: 2071,
      german: 'Waffe des Glaubens',
      english: 'Spiritual Weapon',
      image: 'spiritualWeapon',
      level: 2,
      isCustom: false,
      classes: ['test', 'cleric'],
      timeToCast: 0,
      cost: 'bonus action',
      duration: 1,
      durationType: 'minutes',
      canRitual: false,
      isRitual: false,
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: 1, diceType: 8, damageType: 'force' }],
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
        <p>Du erschaffst eine Schwebende, gespenstische Waffe in Reichweite, die für die Wirkungsdauer anhält oder bis du den Zauber erneut wirkst. Wenn du den Zauber wirkst, kannst du einen Nahkampfangriff gegen eine Kreatur innerhalb von 5 Fuß zur Waffe durchführen. Bei einem Treffer erleidet das Ziel 1W8 + deinen Zaubermodifikator als Energieschaden.</p>
        <p>Als Bonusaktion in deinem Zug kannst du die Waffe bis zu 20 Fuß weit bewegen und den Angriff gegen eine Kreatur innerhalb von 5 Fuß um sie wiederholen.</p>
        <p>Die Waffe kann jede Form annehmen, die du wählst. Kleriker von Gottheiten, die mit einer bestimmten Waffe assoziiert sind (wie St. Cuthbert für seine Keule und Thor für seinen Hammer), lassen den Effekt dieses Zaubers wie diese Waffe aussehen.</p>
        <p><b>Auf höheren Graden:</b> Wirkst du diesen Zauber mit einem Zauberplatz des 3. Grades oder höher, erhöht sich der Schaden um 1W8 für jeden zweiten Grad über dem 2.</p>
      `,
      description_en: `
        <p>You create a floating, spectral weapon within range that lasts for the duration or until you cast this spell again. When you cast the spell, you can make a melee spell attack against a creature within 5 feet of the weapon. On a hit, the target takes force damage equal to 1d8 + your spellcasting ability modifier. As a bonus action on your turn, you can move the weapon up to 20 feet and repeat the attack against a creature within 5 feet of it. The weapon can take whatever form you choose. Clerics of deities who are associated with a particular weapon (as St. Cuthbert is known for his mace and Thor for his hammer) make this spell’s effect resemble that weapon.</p>
        <p><b>At higher levels:</b> When you cast this spell using a spell slot of 3rd level or higher, the damage increases by 1d8 for every two slot levels above 2nd.</p>
      `,
      school: 'evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      diameter: 0,
    },
    {
      id: 2074, // Der Tabelle entnehmen
      german: 'Zone der Wahrheit',
      english: 'Zone of Truth',
      image: 'zoneOfTruth', //Englischer name in lowerCamelCase
      level: 2,
      isCustom: false, // immer false
      classes: ['test', 'bard', 'cleric', 'paladin'], // ALles Klassen + test
      timeToCast: 0, // gerade unwichtig, einfach 0 eintragen
      cost: 'action', // action | bonus | reaction
      duration: 10, // gerade unwichtig, einfach 0 eintragen
      durationType: 'minutes', // rounds | "minutes" | "hours" | "days"
      canRitual: false, // Ob es als Ritual gewirkt werden kann
      isRitual: false, // Ob es als Ritual gewirkt wird -> Wenn es nur als Ritual gewirkt werden kann
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'charisma', // alle attribute auf Englisch und klein
      doesDamage: false,
      damage: [{ diceNumber: 0, diceType: 0, damageType: '' }], // acid | bludgeoning | cold | fire | force | lightning | necrotic | piercing | poison | psychic | radiant | slashing | thunder
      doesHeal: false,
      heal: { diceNumber: 0, diceType: 0, additionalHeal: 0 },
      description_de: `
          <p>Du erschaffst eine magische Zone, die in einem Radius von 4,5 Metern, zentriert auf einen Punkt deiner Wahl innerhalb der Reichweite, vor Täuschung schützt. Bis zum Ende des Zaubers muss eine Kreatur, die den Zauberbereich zum ersten Mal in ihrem Zug betritt oder ihren Zug dort beginnt, einen Rettungswurf auf Charisma ablegen. Bei einem misslungenen Rettungswurf kann die Kreatur keine absichtliche Lüge sprechen, solange sie sich im Radius befindet. Du weißt, ob der Rettungswurf jeder Kreatur gelingt oder misslingt.</p>
          <p>Eine betroffene Kreatur ist sich des Zaubers bewusst und kann daher vermeiden, Fragen zu beantworten, auf die sie normalerweise mit einer Lüge antworten würde. Eine solche Kreatur kann in ihren Antworten ausweichen, solange sie innerhalb der Grenzen der Wahrheit bleibt.</p>
        `,
      description_en: `
          <p>You create a magical zone that guards against deception in a 15-foot-radius sphere centered on a point of your choice within range. Until the spell ends, a creature that enters the spell’s area for the first time on a turn or starts its turn there must make a Charisma saving throw. On a failed save, a creature can’t speak a deliberate lie while in the radius. You know whether each creature succeeds or fails on its saving throw.</p>
          <p>An affected creature is aware of the spell and can thus avoid answering questions to which it would normally respond with a lie. Such creatures can be evasive in its answers as long as it remains within the boundaries of the truth.</p>
        `,
      school: 'enchantment', // alles klein geschrieben
      isRanged: true, // ob es mehr, als 5 Fuß Reichweite hat
      range: 60, // 5 wenn keine Range
      hasAreaOfEffect: true,
      areaOfEffectType: 'sphere', // circle | cone | cube | cylinder | line | sphere
      diameter: 15,
    },
  ];
}
